#
# spec file for package mercurial
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%endif
Name:           mercurial
Version:        4.5.2
Release:        lp151.6.3.1
Summary:        Scalable Distributed SCM
License:        GPL-2.0-or-later
Group:          Development/Tools/Version Control
Url:            https://www.mercurial-scm.org/
Source:         https://www.mercurial-scm.org/release/mercurial-%{version}.tar.gz
Source1:        cacerts.rc
Source2:        https://www.mercurial-scm.org/release/mercurial-%{version}.tar.gz.asc
Source3:        mercurial.keyring
Source99:       mercurial-rpmlintrc
Patch0:         mercurial-hgk-path-fix.diff
# PATCH-FIX-OPENSUSE mercurial-docutils-compat.diff -- Fix for new docutils options not available on 11.1 and older
Patch1:         mercurial-docutils-compat.diff
# PATCH-FIX-OPENSUSE mercurial-locale-path-fix.patch saschpe@suse.de -- locales are found in /usr/share/locale
Patch2:         mercurial-locale-path-fix.patch
# Upstream fixes: CVE-2018-13346 CVE-2018-13347 CVE-2018-13348
Patch11:        hg-mpatch-fix01.patch
Patch12:        hg-mpatch-fix02.patch
Patch13:        hg-mpatch-fix03.patch
Patch14:        hg-mpatch-fix04.patch
Patch15:        hg-mpatch-fix05.patch
Patch16:        hg-mpatch-fix06.patch
Patch17:        hg-mpatch-fix07.patch
Patch18:        hg-mpatch-fix08.patch
Patch19:        hg-mpatch-fix09.patch
Patch20:        hg-CVE-2018-17983.patch
Patch21:        hg-CVE-2019-3902-fix1.patch
Patch22:        hg-CVE-2019-3902-fix2.patch
Patch23:        hg-CVE-2019-3902-fix3.patch
BuildRequires:  fdupes
BuildRequires:  python-devel
BuildRequires:  python-xml
Requires:       python
Requires:       python-curses
Requires:       python-xml
Recommends:     %{name}-lang
Provides:       hg = %{version}
%if 0%{?suse_version} < 1210
BuildRequires:  docutils
%else
BuildRequires:  python-docutils
%endif
%if 0%{?sles_version}
Requires:       openssl-certs
%else
Requires:       ca-certificates
%endif
%if 0%{?with_tests}
Source90:       tests.blacklist
BuildRequires:  bzr
BuildRequires:  git
BuildRequires:  gpg
BuildRequires:  ncurses-devel
BuildRequires:  python-Pygments
BuildRequires:  python-openssl
BuildRequires:  subversion-python
BuildRequires:  unzip
#BuildRequires:  python-pyflakes
%endif

%description
Mercurial is a fast, lightweight source control management system
designed for efficient handling of very large distributed projects.

%lang_package

%prep
%setup -q
%patch0
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%patch1
%endif
%patch2 -p1
%patch11 -p1
%patch12 -p1
%patch13 -p1
%patch14 -p1
%patch15 -p1
%patch16 -p1
%patch17 -p1
%patch18 -p1
%patch19 -p1
%patch20 -p1
%patch21 -p1
%patch22 -p1
%patch23 -p1
chmod 644 hgweb.cgi

%build
make %{?_smp_mflags} all

%install
make install PREFIX="%{_prefix}" DESTDIR=%{buildroot}

# Move locales to proper location
mkdir -p %{buildroot}%{_datadir}/locale
mv %{buildroot}%{python_sitearch}/mercurial/locale/* %{buildroot}%{_datadir}/locale
%find_lang hg

# Install stuff in contrib
install -m0755 contrib/hgk %{buildroot}%{_bindir}
install -Dm0644 contrib/bash_completion %{buildroot}%{_sysconfdir}/bash_completion.d/mercurial.sh
install -Dm0644 contrib/zsh_completion %{buildroot}%{_datadir}/zsh/site-functions/_mercurial
mkdir -p %{buildroot}%{_datadir}/{x,}emacs/site-lisp
install -m0644 contrib/*.el %{buildroot}%{_datadir}/emacs/site-lisp
install -m0644 contrib/*.el %{buildroot}%{_datadir}/xemacs/site-lisp
install -Dm0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/mercurial/hgrc.d/cacerts.rc
%fdupes -s %{buildroot}%{_prefix}

%if 0%{?with_tests}
%check
make %{?_smp_mflags} tests TESTFLAGS="-v --blacklist=%{SOURCE90}"
%endif

%files lang -f hg.lang

%files
%license COPYING
%doc README.rst CONTRIBUTORS hgweb.cgi
%{_bindir}/*
%{_sysconfdir}/bash_completion.d/*
%{_datadir}/zsh/
%dir %{_sysconfdir}/mercurial
%dir %{_sysconfdir}/mercurial/hgrc.d
%config %{_sysconfdir}/mercurial/hgrc.d/*
%{_datadir}/emacs
%{_datadir}/xemacs
%{_mandir}/man1/hg.1%{?ext_man}
%{_mandir}/man5/hgignore.5%{?ext_man}
%{_mandir}/man5/hgrc.5%{?ext_man}
%{_mandir}/man8/hg-ssh.8%{?ext_man}
%{python_sitearch}/*

%changelog
* Tue May 14 2019 tiwai@suse.de
- Fix incorrect patch-checking with symlinks and subrepos
  (CVE-2019-3902, bsc#1133035):
  hg-CVE-2019-3902-fix1.patch
  hg-CVE-2019-3902-fix2.patch
  hg-CVE-2019-3902-fix3.patch
* Tue Oct  9 2018 tiwai@suse.de
- Fix out-of-bounds read during parsing of a malformed manifest
  entry (CVE-2018-17983, bsc#1110899):
  hg-CVE-2018-17983.patch
* Fri Jul  6 2018 tiwai@suse.de
- Fix security issues in mpatch overflow and other misbehavior
  (CVE-2018-13346, bsc#1100354, CVE-2018-13347, bsc#1100355,
  CVE-2018-13348, bsc#1100353):
  hg-mpatch-fix01.patch
  hg-mpatch-fix02.patch
  hg-mpatch-fix03.patch
  hg-mpatch-fix04.patch
  hg-mpatch-fix05.patch
  hg-mpatch-fix06.patch
  hg-mpatch-fix07.patch
  hg-mpatch-fix08.patch
  hg-mpatch-fix09.patch
* Sat Mar 10 2018 develop7@develop7.info
- Modernize spec-file by calling spec-cleaner
* Wed Mar  7 2018 develop7@develop7.info
- Mercurial 4.5.2
  (4.5.2 was released immediately after 4.5.1 to fix a release oversight.)
  1. Security Fixes (CVE-2018-1000132,bsc#1085211)
    All versions of Mercurial prior to 4.5.2 have vulnerabilities in the HTTP
    server that allow permissions bypass to:
  * Perform writes on repositories that should be read-only
  * Perform reads on repositories that shouldn't allow read access
  2. Backwards Compatibility Changes
    The "batch" wire protocol command now enforces permissions of each invoked
    sub-command. Wire protocol commands must define their operation type or the
    "batch" command will assume they can write data and will prevent their
    execution on HTTP servers unless the HTTP request method is POST, the
    server is configured to allow pushes, and the (possibly authenticated) HTTP
    user is authorized to perform a push.
    Wire protocol commands not defining their operation type in
    "wireproto.PERMISSIONS" are now assumed to be used for "push" operations
    and access control to run those commands is now enforced accordingly.
  3. Bug Fixes
    fileset: don't abort when running copied() on a revision with a removed file
    date: fix parsing months
    setup: only allow Python 3 from a source checkout (issue5804)
    annotate: do not poorly split lines at CR (issue5798)
    subrepo: don't attempt to share remote sources (issue5793)
    subrepo: activate clone pooling to enable sharing with remote URLs
    changegroup: do not delta lfs revisions
    revlog: do not use delta for lfs revisions
    revlog: resolve lfs rawtext to vanilla rawtext before applying delta
  See full cnahgelog on
  https://www.mercurial-scm.org/wiki/WhatsNew#Mercurial_4.5.1_.2F_4.5.2_.282018-03-06.29
* Sun Feb  4 2018 develop7@develop7.info
- Mercurial 4.5
  See full changelog on
  https://www.mercurial-scm.org/wiki/WhatsNew#Mercurial_4.5-rc_.282018-01-22.29
  1. New Features
    1.1. revert --interactive
    The revert command now accepts the flag --interactive to allow reverting
    only some of the changes to the specified files.
    1.2. Accessing hidden changesets
    Set config option `experimental.directaccess = True` to access hidden
    changesets from read only commands.
    1.3. githelp extension
    The githelp extension provides the `hg githelp` command. This command
    attempts to convert a git command to its Mercurial equivalent. The
    extension can be useful to Git users new to Mercurial.
    1.4. Largefiles changes
    largefiles: add a 'debuglfput' command to put largefile into the store
    largefiles: add support for 'largefiles://' url scheme
    largefiles: allow to run 'debugupgraderepo' on repo with largefiles
    largefiles: convert EOL of hgrc before appending to bytes IO
    largefiles: explicitly set the source and sink types to 'hg' for lfconvert
    largefiles: modernize how capabilities are added to the wire protocol
  2. hgweb changes
    hgweb now shows more information about commits: phase (if it's not public),
    obsolescence status (with a short explanation and links to the successors)
    and instabilities (e.g. orphan, phase-divergent or content-divergent).
    Client-side graph code has been simplified by delegating more work to the
    backend, so /graph page is now more in sync with /log page, visually and
    feature-wise. Unfortunately, this code change means that 3rd-party themes
    for 4.5+ are required to have graphentry.tmpl template available (copy it
    from the base theme if you don't use %%include and then reference it in map
    file) and render entries in graph.tmpl -- look at one of the core themes to
    see what it needs to look like. JS functions that create graph vertices and
    edges are now available in Graph.prototype, making it possible to call the
    original functions from custom theme-specific functions if needed.
    Graph now shows different symbols for normal, branch-closing, obsolete and
    unstable commits, and marks currently checked out commit with a circle
    around its graph node.
    There's also now json-graph API endpoint that can be used for rendering
    commit graph in 3rd-party applications.
  2.1. Other Changes
    When interactive revert is run against a revision other than the working
    directory parent, the diff shown is the diff to _apply_ to the working
    directory, rather than the diff to _discard_ from the working copy. This is
    in line with related user experiences with 'git' and appears to be less
    confusing with 'ui.interface=curses'.
    Let 'hg rebase' avoid content-divergence by skipping obsolete changesets
    (and their descendants) when they are present in the rebase set along with
    one of their successors but none of their successors is in destination.
    A new experimental config flag, `rebase.experimental.inmemory`, makes
    rebase perform an in-memory merge instead of doing it on-disk in the
    working copy.
    The `HGPLAINEXCEPT` environment variable can now include color to allow
    automatic output colorization in otherwise automated environments.
    A new `unamend` command in `uncommit` extension which undoes the effect of
    the amend command by creating a new changeset which was there before amend
    and moving the changes that were amended to the working directory.
    A '--abort' flag to merge command to abort the ongoing merge.
    An experimental flag '--rev' to 'hg branch' which can be used to change
    branch of changesets.
    bundle2 read I/O significantly improved
    bundle2 memory use significantly reduced during read
    clonebundle: it is now possible to serve the clonebundle using a git-lfs
    compatible server.
    templatefilters: add slashpath() to convert path separator to slash
    (issue5572)
    A new experimental config flag, 'inline-color-diff', adds within-line color
    diff capacity
    histedit: add support to output nodechanges using formatter to help with
    editor integrations
  3. Backwards Compatibility Changes
    `log --follow-first -rREV`, which is deprecated, now follows the first
    parent of merge revisions from the specified REV just like
    `log --follow -rREV`.
    `log --follow -rREV FILE..` now follows file history across copies and
    renames.
    transaction: register summary callbacks only at start of transaction
    hgweb's graph view no longer supports browsers that lack <canvas> support
    hgweb: only include graph-related data in jsdata variable on /graph pages
    graphlog: add another graph node type, unstable, using character *
    remove: print message for each file in verbose mode only while using '-A'
* Sat Nov 11 2017 develop7@develop7.info
- Mercurial 4.4.1
  1. Notable changes
  * Git and Subversion subrepos have been disabled by default to mitigate a
    potential security risk if files overlapping with a subrepo managed to be
    committed to a repository.
    bsc#1071715 CVE-2017-17458
  * Subrepos are now more paranoid about symlink traversal.
  * The share extension handles drive letters on Windows better.
  It is possible that a specially malformed repository can cause Git
  subrepositories to run arbitrary code in the form of a .git/hooks/post-update
  script checked in to the repository in Mercurial 4.4 and earlier. Typical use
  of Mercurial prevents construction of such repositories, but they can be
  created programmatically.
* Sun Nov  5 2017 develop7@develop7.info
- Mercurial 4.4
  Notable changes
    Control whitespace settings for annotation on hgweb
  * /annotate URLs on hgweb now accept query string arguments to influence how
    whitespace changes impact results.
  * The arguments "ignorews," "ignorewsamount," "ignorewseol," and
    "ignoreblanklines" now have the same meaning as their [annotate] config
    section counterparts. Any provided setting overrides the server default.
  * HTML checkboxes have been added to the paper and gitweb themes to expose
    current whitespace settings and to easily modify the current view.
    Fast, heuristic copy-tracing
    A new fast heuristic algorithm for copytracing which assumes that the
    files moves are either:
    1. renames in the same directory
    2. moves in other directories with same names
    You can use this algorithm by setting 'experimental.copytrace=heuristics'.
    This setting performs full copytracing if both source and destination
    branches contains non-public changesets only.
    Other changes
  * Estimated time is more accurate with non-linear progress
  * "hg status -v" can now show unfinished state. For example, when in an
    unfinished rebase state, "hg status -v" might show:
    [#] The repository is in an unfinished *rebase* state.
    [#] No unresolved merge conflicts.
    [#] To continue:                hg rebase --continue
    [#] To abort:                   hg rebase --abort
  * Added '--ignore-space-at-eol' diff option to ignore whitespace
    differences at line endings.
  * show: use consistent node length in views
  * show: decrease minimum displayed hash length from 5 to 4
  * A new uncommit extension which provides 'hg uncommit' using which one
    can uncommit part or all of the changeset. This command undoes the
    effect of a local commit, returning the affected files to their
    uncommitted state.
  * 'hg clone --uncompressed' uses clone bundles when possible
  * 'hg annotate --skip' now prints a '*' on lines with skipped revisions
  * New 'commands.update.check' feature to adjust constraints on when
    'hg update' will allow updates with a dirty working copy.
  * Add an experimental -L/--line-range FILE,FROMLINE:TOLINE option to
    'hg log' command to follow the history of files by line range. In
    combination with -p/--patch option, only diff hunks within specified
    line range will be displayed. Feedback, especially on UX aspects, is
    welcome.
  * Print warning when fsmonitor isn't being used on a large repository
  Read rest of the changelog at
  https://www.mercurial-scm.org/wiki/WhatsNew#Mercurial_4.4_.282017-11-01.29
- Mercurial 4.3.3
  * Prevent crashes when clearing progress bar. (issue5684)
  * rebase: move bookmarks with --keep (issue5682)
- Mercurial 4.3.2
  * restore compatibility with older versions of Python 2.7 by not using a
    bytearray with struct.unpack_from()
  * restore mingw compatibility for setup.py
  * hgwebdir: read 'web.template' untrusted (plugs potential security issue)
  * repair: preserve phase when not using generaldelta (issue5678)
  * ssh: fix flakey ssh errors on BSD systems
  * restore error handling behavior around certain I/O errors; the regressed
    behavior could result in transactions not being properly rolled back if
    stdio handles encountered errors (issue5658)
  * templatekw: choose {latesttag} by len(changes), not date (issue5659)
  * record: fix revert -i for lines without newline (issue5651)
  * mq: create non-lossy patches, also with custom global diff configuration
- Fixed README file name (now it's README.rst)
* Tue Aug 15 2017 tiwai@suse.de
- Mercurial 4.3.1:
  This is a regularly-scheduled quarterly feature release,
  including the previous two security fixes (CVE-2017-1000115,
  CVE-2017-1000116)
  Notable changes:
  * experimental amend extension providing the amend command
  * experimental sparse extension
  * Support for Python 2.6 has been dropped.
  * Bundles created by the strip extension now store phase
    information. It will be restored when unbundling.
  * The strip extension now removes relevant obsmarkers.
    If a backup requested (the default), the obsmarkers are stored
    in the backup bundle and will be restored when unbundling.
  * hg show work (from the experimental show extension) now
    displays more info
  * hg show stack is a new view for the current, in-progress
    changeset and others around it
  * Mitigation for two security vulnerabilities
* Thu Aug 10 2017 tiwai@suse.de
- mercurial 4.2.3: security fix updates for
  CVE-2017-1000115 and CVE-2017-1000116:
  * Mercurial's symlink auditing was incomplete prior to 4.3, and
    could be abused to write to files outside the repository
    (CVE-2017-1000115 bsc#1053344)
  * Mercurial was not sanitizing hostnames passed to ssh, allowing
    shell injection attacks by specifying a hostname starting with
  - oProxyCommand (CVE-2017-1000116, bsc#1052696)
* Wed Jul  5 2017 develop7@develop7.info
- Mercurial 4.2.2
  This is a regularly-scheduled bugfix release.
  * largefiles: avoid a crash when archiving a subrepo with largefiles disabled
  * rebase: also test abort from pretxnclose error
  * rebase: backed out changes 2519994d25ca and cf8ad0e6c0e4 (issue5610)
  * rebase: reinforce testing around precommit hook interrupting a rebase
- Mercurial 4.2.1
  This is a regularly-scheduled bugfix release.
  * `hg graft` now works when grafting across merges that were problematic
    before (b4e1e30528c7).
  * A race condition in `hg status` was partially fixed (issue5584).
  * The message about deprecated SHA-1 hashes in the [hostfingerprints] config
    section now references the correct syntax for replacing them with SHA-256
    hashes (issue5559).
* Sun May  7 2017 develop7@develop7.info
- Mercurial 4.2
  This is a regularly-scheduled quarterly feature release.
  * Notable changes
    + Pager support has been moved into core and is now enabled by default.
    This is now controlled with the ui.paginate setting.
    Note that in 4.2-rc, the ui.paginate option was named pager.enable. The
    old name has been dropped in the final release. If you had turned
    pagination off using pager.enable=False, please update your config.
    + Color support has also been moved into core and is now enabled by default
    (the ui.color setting now defaults to 'auto').
    + The new experimental 'show' extension provides a way to view various
    information about your repository in an ergonomic way. It is deliberately
    designed for human consumption and not for scripting, so it doesn't carry
    the same backward compatibility guarantees as other commands. See
    'hg help -e show' for more information.
    + Mercurial now requires `setuptools` on Windows
* Tue Apr  4 2017 develop7@develop7.info
- Mercurial 4.1.2
  This is a regularly-scheduled bugfix release.
  + Mercurial should work inside IIS on Windows again. (issue5493)
  + zstd support now refuses to work on old bundle formats. (issue5506)
  + Merges involving subrepositories no longer crash in some cases. (issue5505)
  + Checking for new heads during push is no longer accidentally quadratic
- Mercurial 4.1.1
  This is a regularly-scheduled bugfix release.
  + Several incorrect mailing list addresses have been corrected.
  + Various error cases have been corrected during push and pull.
  + Minor issues that happened when Mercurial spawned worker processes have
    been fixed.
* Wed Feb  1 2017 develop7@develop7.info
- Mercurial 4.1
  This is a regularly-scheduled quarterly feature release.
  + Features
  * A new extensible "compression engines" API has been implemented. Support
    for a new compression format can now be implemented in extensions.
  * New compression formats are fully supported in bundles and the wire
    protocol. There is experimental support for different compression in
    revlogs.
  * zstd - a new and exciting compression engine - is now distributed with
    Mercurial and built by default
  * HTTP payloads for many commands will now use zstd by default (as opposed
    to zlib) when both client and server support it. This can reduce
    server-side CPU usage to ~60%% of original for operations like serving
    bundles.
  * zstd compressed bundles can be produced by specifying the `zstd` bundle
    type. e.g. `hg bundle -a -t zstd-v2 zstd-bundle.hg`.
  * A new statistical profiler has been added and made the default profiler
    for `--profile`. This profiler gives more accurate results than Python's
    built-in cProfile (the previous default) because the profiler overhead is
    much smaller. The output from `--profile` now displays the code hot path
    by default. This allows Mercurial developers to more accurately identify
    performance problems.
  * New `followlines(file, from:to, startrev=.)` revset predicate to track a
    part of changes.
  * Experimental support for additional git-diff features.
  * Troubled changes (from ChangesetEvolution) are noted more prominently in a few places.
  * An experimental hg debugupgraderepo command allows in-place upgrading of
    repositories to the latest storage format.
  + Improvements
  * Performance of reading individual revlog entries has been greatly
    improved. This will be noticeable when performing changelog scans on
    large repositories (such as when executing certain revsets).
  * The low-level content diffing algorithm is now ~2x faster. Operations
    that write data to the repository (like commit) can be noticeably faster
    as a result.
  See complete changelog at
  https://www.mercurial-scm.org/wiki/WhatsNew#Mercurial_4.1_.282017-2-1.29
- refreshed mercurial-locale-path-fix.patch and mercurial-hgk-path-fix.diff
- refresh package keyring
* Fri Jan  6 2017 mpluskal@suse.com
- Update to version 4.0.2:
  * demandimport: do not raise ImportError for unknown item in
    fromlist
  * posix: make poll() restart on interruption by signal
  * hgweb: add missing slash to file log url in rss style
  * hgweb: cache fctx.parents() in annotate command
  * vfs, scmutil: ignore EPERM at os.utime, which avoids ambiguity
- Update package keyring
* Wed Nov  2 2016 develop7@develop7.info
- Mercurial 4.0
  This is a regularly-scheduled quarterly feature release. Unlike other
  4.0 software releases, this is simply 3.9 + .1, so it should be the usual
  pain-free upgrade.
  + Features
  * The following commands now also have experimental formatter support:
    'hg version', 'hg grep' and 'hg config'
  * New template keywords and functions: `termwidth`, `mod(a, b)`,
    `relpath(path)`
  * Basic arithmetic operations in template such as `termwidth - 10`
  * `follow()` revset takes new `startrev` parameter
  * Bash completion now allows skipping potentially expensive status call
    for completing 'hg status' arguments, using $HGCOMPLETE_NOSTATUS
    environment variable
  + Improvements
  * A number of changes were made to move and copy tracking, to make sure
    move and copy information is not lost during commands like 'hg graft'
  * Compound revset expression is now properly ordered
  * Python 3 support has received a lot of improvements (but will take a
    lot of additional work)
  * zlib performance in hgweb is improved, and it's possible to control zlib
    compression level using server.zliblevel option
- Refreshed mercurial-hgk-path-fix.diff and mercurial-locale-path-fix.patch
* Mon Sep 19 2016 develop7@develop7.info
- Mercurial 3.9.1 (2016-9-1)
  This is a regularly-scheduled bugfix release.
  * bundle2: fail faster when interrupted
  * bundle2: localize handleoutput remote prompts
  * convert: move svn config initializer out of the module level
  * debian: update source URL in copyright file
  * exchange: correctly specify url to unbundle (issue5145)
  * help: add example of '[templates]' usage
  * help: update link to wiki/CommandServer
  * osx: update bugzilla link in readme
  * revset: fix keyword arguments to go through optimization process
  * win32: update link to mailing list in readme
  * win32: update wiki link in mercurial.ini
* Mon Aug  1 2016 develop7@develop7.info
- Mercurial v3.9
  + Features
  * ui.textwidth can now be set to define width of help text
  * separate() template function added
  * ui.rollback can be set to false to disable the hg rollback command
  * fail-<command> hooks now run when a command fails
  * experimental.graphstyle.* config options to control styling of graphs in
    console
  * experimental.histedit.autoverb allows histedit lines beginning with
    "verb!" to be interpreted as histedit actions
  * [hostsecurity] config section for defining advanced per-host security
    settings
  * ability to define the SHA-256 and SHA-512 hashes of pinned server
    certificates
  * ability to define CA certificates on a per-host basis
  * ability to define the minimum TLS protocol version on a global or
    per-host basis
  * sort() revset can now perform topological sorts using the topo option
  * hgweb can now render JSON for filelog, filerevision, summary, and search
    web commands
  * [paths] entries can now define a pushrev sub-option to control which
    revisions to push by default
  * The experimental 'journal' extension was added, allowing users to view
    the previous positions of bookmarks and the working copy
  + Improvements
    This release includes many improvements, including (but not limited to):
  * performance of `hg diff` has been improved
  * chg now detects more changes to the configuration and execution
    environment
  * SSL/TLS code has been significantly refactored and now is consistent
    across all consumers (HTTPS, SMTPS)
  * performance improvements to server communication (particularly for the
    largefiles and remotefilelog extensions)
  * connections to servers whose certificate authority (CA) is unknown are
    now refused even if no CA certificates are available (see SecureConnections for details)
  * fingerprints of server certificates are now printed using SHA-256
    instead of SHA-1
  * reads and writes to certain files is now robust and avoids more race
    conditions and edge cases (see ExactCacheValidationPlan)
  * performance improvements to certain revsets
  * cloning will no longer prompt for a password multiple times when cloning
    from a server that requires a password
  * annotate view in hgweb now groups lines into blocks depending on their
    revision and highlights lines for the current revision
  * hgweb now displays extra information and also navigation links in popups
    for each line in annotate view
* Sun Jun 12 2016 astieger@suse.com
- mercurial 3.8.3:
  * bookmarks: allow pushing active bookmark on new remote head
  * localrepo: prevent executable-bit only changes from being lost on amend
  * strip: invalidate phase cache after stripping changeset
- verify source signature
* Tue May 17 2016 develop7@develop7.info
- Mercurial v3.8.2
  This is an unscheduled bugfix release. 3.8.1 contained a noisy deprecation
  warning that was only intended for Mercurial developers, sorry.
  * bookmarks: properly invalidate volatile sets when writing bookmarks
  * builddeb: add distroseries to tagged versions
  * bundle2: properly request phases during getbundle
  * debian: add wish to suggests
  * debian: forgot to make debian/rules executable in 6b95a623ec90
  * deprecation: gate deprecation warning behind devel configuration
  * help: fix the display for hg help internals.revlogs (issue5227)
  * help: search section of help topic by translated section name correctly
  * hg-ssh: copy doc string to man page
  * patch: show lower-ed translated message correctly
  * progress: stop excessive clearing (issue4801)
* Tue May  3 2016 develop7@develop7.info
- fix mercurial-locale-fix.patch
* Mon May  2 2016 develop7@develop7.info
- update to v3.8.1
  (3.8.1 was released immediately after 3.8 to fix a release oversight.)
  Regularly scheduled feature release. This release contains a low-priority security fix for:
  * CVE-2016-3105 Mercurial: arbitrary code execution when converting Git repos
  Features
  * `hg update` and other commands that can perform update (such as hg pull -u)
    now warn about other topological heads
  * cHg has been added
  * `hg update` now updates to the tip-most changeset on the same topological
    branch. Before, it would update to the tip-most changeset, possibly on a
    different topological head
  * Hints on how to continue interrupted commands are now printed
    (e.g. `hg resolve -m` will now tell you to run `hg rebase --continue` or
    `hg histedit --continue`)
  * The experimental automv extension has been added. This extension attempts
    to detect file copes and renames automatically.
  * The 3rd party hgwatchman extension has been imported as the fsmonitor
    extension. This extension uses filesystem watching to make commands like
    `hg status` significantly faster on large repositories.
  * `hg rebase` now chooses its default destination the same way `hg merge` does
  * `hg pull -u` now activates a bookmark if the has a bookmark
  * `hg pull -u` now deactivates a bookmark if the destination doesn't match
    the existing bookmark
  * Improved edge styles in graph log.
  * User template keywords and functions can be defined in `[templatealias]`
    section.
  * It's now possible to push the active bookmark using `hg push -B .`.
  Improvements
  This release includes many improvements, including (but not limited to):
  * performance of copy detection during rebases has been improved, potentially
    leading to faster rebase execution
  * performance of `hg log -f <file>` has been improved
  * syntax errors in loaded extensions are now handled better
  * `hg update` on Windows should now be up to 4x faster
  * JSON encoding should now be proper UTF-8 for all inputs
  * Performance of the - revset operator has been improved
  * The blackbox extension now logs more data
  * "hgext" is now a Python namespace package
  * revsets accessing changelog data (commit messages, authors, dates) are now
    10-15%% faster
  * hg.exe built in MinGW will now link against the proper Python DLL
* Wed Mar 30 2016 develop7@develop7.info
- update to v3.7.3
  This is an out of cycle release to address three security issues:
  * CVE-2016-3630 Mercurial: remote code execution in binary delta decoding
    Mercurial prior to 3.7.3 contained two bounds-checking errors in its binary
    delta decoder that may be exploitable via clone, push, or pull.
  * CVE-2016-3068 Mercurial: arbitrary code execution with Git subrepos
    Mercurial prior to 3.7.3 allowed URLs for Git subrepos that could result in
    arbitrary code execution on clone. This is a further side-effect of Git
    CVE-2015-7545. Reported by Blake Burkhart.
  * CVE-2016-3069 Mercurial: arbitrary code execution when converting Git repos
    Mercurial prior to 3.7.3 allowed arbitrary code execution when converting
    Git repos with hostile names. This could affect automated conversion
    services. Reported by Blake Burkhart.
  + bdiff: (pure) support array.array arrays (issue5130)
  + convert: add new, non-clowny interface for shelling out to git (SEC)
  + convert: dead code removal - old git calling functions (SEC)
  + convert: rewrite calls to Git to use the new shelling mechanism (SEC)
  + convert: rewrite gitpipe to use common.commandline (SEC)
  + convert: test for shell injection in git calls (SEC)
  + files: don't recurse into subrepos without a path or -S (issue5127)
  + hg: perform update after pulling during clone with share (issue5103)
  + mq: restrict generated patch name to 75 characters (issue5117)
  + obsolete: fix n^2 marker computation behavior
  + parsers: detect short records (SEC)
  + parsers: fix list sizing rounding error (SEC)
  + streamclone: fix error when store files grow while stream cloning
  + subrepo: adapt to git's recent renames-by-default
  + subrepo: set GIT_ALLOW_PROTOCOL to limit git clone protocols (SEC)
* Sun Mar 13 2016 develop7@develop7.info
- update to v3.7.2
  This is a regularly-scheduled bugfix release.
  + bundlerepo: properly handle hidden linkrev in filelog (issue4945)
  + bundlerepo: properly handle hidden linkrev in manifestlog (issue4945)
  + demandimport: add _imp to ignore list
  + doc: correct example concerning "hg purge" alias in man page "hgrc.5"
  + doc: remove deprecated option from synopsis of command help
  + fileset: fix copy/paste in eol() error message
  + help: fix typo in backgroundclose documentation
  + help: hg.intevation.de is new primary name of hg.intevation.de (and new cert)
  + help: update template examples to use reST literal syntax
  + hg: obtain lock when creating share from pooled repo (issue5104)
  + log: fix order of revisions filtered by multiple OR options (issue5100)
  + rebase: update working directory when aborting (issue5084)
  + revert: properly revert to ancestor of p2 during merge (issue5052)
  + revset: flatten chained 'list' operations (aka function args) (issue5072)
  + setup: avoid procedure related to hg.exe at setup.py --pure
  + ui: fix crash by non-interactive prompt echo for user name
  + unionrepo: properly handle hidden linkrev in revlog (issue5070)
  + zeroconf: forward all arguments passed to ui.configitems() wrapper
* Thu Feb 11 2016 wr@rosenauer.org
- update to 3.7.1
  This addresses an urgent regression in compilation on Solaris
  and metadata handling for conversions.
  + amend: don't preserve most extra fields
  + graft: don't preserve most extra fields
  + histedit: fix typo in documentation
  + osutil: disable compilation of recvfds() on unsupported platforms
  + osutil: do not abort loading pure module just because libc has no recvmsg()
  + rebase: backout changeset 986d04b9fedd
  + rebase: backout changeset d755a9531fce
  + rebase: don't preserve most extra fields
* Tue Feb  2 2016 develop7@develop7.info
- update to v3.7
  * Features
    + Generaldelta: the original Mercurial compression format had an inefficient way of storing history in very branchy
    repositories. Generaldelta addresses this weakness. As a result, depending on the repository, this can improve
    the size of the history up to a factor of 10. Mercurial 1.9 was the first release to support generaldelta
    (behind a feature flag), but Mercurial 3.7 also allows pulling a mixture of non-generaldelta and generaldelta
    history without having to recompute everything, which avoids overloading servers. As a result, generaldelta is
    now enabled by default. You can convert a repository to generaldelta using:
    `hg clone -U --config format.generaldelta=1 --pull originalrepo generaldeltarepo`
    + Clonebundles: this is an server-side extension. It allows using a pre-generated bundle for an initial Mercurial
    clone. Clients will automatically use clonebundles if a server advertises them. Clonebundles allows much faster
    initial clones and reduces the load on a central server significantly. Mercurial 3.6 was the first version to
    include experimental clonebundles support, it's now been marked non-experimental. You can find out more using:
    `hg help clonebundles`.
    + Filesets now support 'missing()', to specify all files missing according to `hg status`.
    + Interactive committing (`hg commit -i`) and amending (`hg commit --amend`) can now be used together.
    + Merging can now handle collisions between untracked and tracked files, configurable according to the config
    option `merge.checkunknown`.
    + Default 'histedit' destination: it's now possible to run `hg histedit` without specifying a base revision.
    Mercurial will try to determine an appropriate base automatically. The revset used for this is
    "`reverse(only(.) and not public() and not ::merge())`", which specifies the first ancestor of the current
    changeset that is not public and does not have any descendants that are merges.
    + The '*.orig' files created by revert can now be stored in a different location, specified by the config option
    `ui.origbackuppath`.
    + `hg shelve` now supports storing untracked files.
    + `hg unshelve` now supports using a custom merge tool.
    + `hg backout` now commits by default if no conflicts were encountered.
    + hgweb now supports rendering sub-topics.
    + Server operators can now limit interaction with legacy clients speaking an outdated wire protocol. This is useful
    for preventing excessive CPU use when the server is using generaldelta repositories. See the various `bundle1`
    options in `hg help config.server`.
    + Python wheel packages are now available for Windows on PyPI
    + `[paths]` entries can now define a separate URL for pushes. See `hg help config.paths` for more.
  * Improvements
    This release includes many improvements, including (but not limited to):
    + performance improvements (speedup for '`hg log <file/folder>`')
    + many documentation improvements (clarification, additional examples (see `hg help <command> --verbose`), ...)
    + improved PyPy support
    + `hg clone --uncompressed` is now 3-4x faster on Windows. See the `backgroundclose*` options in
    `hg help config.worker` for more.
* Sun Dec  6 2015 wr@rosenauer.org
- update to 3.6.2
  This is a regularly-scheduled bugfix release.
  + docker: match more version of 'hg docker version'
  + localrepo.commit: check all files for resolve state
  + rebase: add returning value from pullrebase function
  + resolve: restore .orig only after merge is fully complete
  + share: wrap bmstore._writerepo for transaction sensitivity
  + tags: create new sortdict for performance reasons
* Wed Nov 11 2015 wr@rosenauer.org
- update to 3.6.1
  This is an out-of-cycle bugfix release for issues related to hooks
  See detailed release notes on
  https://www.mercurial-scm.org/wiki/WhatsNew#Mercurial_3.6.1_.282015-11-9.29
* Sun Nov  8 2015 wr@rosenauer.org
- update to 3.6
  Regularly-scheduled feature release.
  See detailed release notes on
  https://www.mercurial-scm.org/wiki/WhatsNew#Mercurial_3.6_.282015-11-1.29
* Sun Oct  4 2015 wr@rosenauer.org
- update to 3.5.2
  Regularly-scheduled bugfix release.
  + hgweb: use latest mtime for caching tag (issue4814)
  + largefiles: restore archiving largefiles with hgweb (issue4859)
  + localrepo: recreate phasecache if changelog was modified (issue4855)
  + monoblue: fix page subtitle on help pages
  + unbundle: cleanly abort on unknown bundle2 feature
* Mon Sep 14 2015 wr@rosenauer.org
- update to 3.5.1
  Regularly-scheduled bugfix release
  + convert: fix git copy file content conversions
  + filesets: ignore unit case in size() predicate for single value
  + help: fix typo familar -> familiar
  + help: fix typo in scripting documentation
  + hg: avoid auto sharing when the clone destination is remote
  + hgweb: fix trust of templates path (BC)
  + histedit: backout ebb5bb9bc32e
  + largefiles: ensure lfutil.getstandinmatcher() only matches standins
  + match: fix a case-only rename + explicit path commit on icasefs (issue4768)
  + parsers: fix memory leak in compute_phases_map_sets
  + rebase: lock the repo during the full rebase operation
  + revset: prevent crash caused by empty group expression while optimizing "and"
  + revset: prevent crash caused by empty group expression while optimizing "or"
  + strip: use the 'finally: tr.release' pattern during stripping
  + update: wlock the repo for the whole 'hg update' command
- require python-curses (boo#944183)
* Tue Aug  4 2015 develop7@develop7.info
- update to v3.5
  Regularly-scheduled feature release.
  See detailed release notes on
  https://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.5_.282015-07-31.29
* Sat Jul 25 2015 develop7@develop7.info
- update to v3.4.2
  See detailed release notes on
  https://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.4.2_.282015-07-01.29 and
  https://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.4.1_.282015-06-01.29
* Sun May  3 2015 develop7@develop7.info
- update to 3.4
  This is a regularly-scheduled feature release.
  See full release notes at
  http://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.4_.282015-05-01.29
* Fri Apr  3 2015 wr@rosenauer.org
- update to 3.3.3
  This is a regularly-scheduled bugfix release.
  + adjustlinkrev: handle 'None' value as source
  + adjustlinkrev: prepare source revs for ancestry only once
  + amend: check for directory renames for both merge parents
    (issue4516)
  + annotate: reuse ancestry context when adjusting linkrev (issue4532)
  + dirstate: don't require exact case when adding dirs on icasefs
    (issue4578)
  + dirstate: make sure rootdir ends with directory separator
    (issue4557)
  + filemerge: clean up language in mergemarkertemplate help
  + forget: cleanup the output for an inexact case match on icasefs
  + hgweb: prevent loading style map from directories other than
    specified paths
  + mergecopies: reuse ancestry context when traversing file history
    (issue4537)
  + templates: fix "log -q" output of default style
  + templates: fix "log -q" output of phases style
  + win32: 'raise ctypes.WinError' -> 'raise ctypes.WinError()'
* Fri Mar  6 2015 matwey.kornilov@gmail.com
- Without installed python package hg is not able to clone https links,
  and it is not so easy to understand from error message:
  "python ssl support not found".
* Tue Mar  3 2015 develop7@develop7.info
- update to v3.3.2
  An unscheduled bugfix release to fix the fix.
  + transaction: really disable hardlink backups (issue4546)
- update to v3.3.1
  This is a regularly scheduled bugfix release. It fixes a significant regression with transactions on Windows network shares.
  + dispatch: work around UnicodeDecodeError caused by SSLError of Python 2.7.9
  + hgweb: recreate old DOM structure for css in monoblue style
  + largefiles: access to specific fields only if largefiles enabled (issue4547)
  + log: fix json-formatted output when file copies are listed (issue4523)
  + repoview: invalidate cached changelog if _delayed changes (issue4549)
  + revisionbranchcache: fall back to slow path if starting readonly (issue4531)
  + revset: mask specific names for named() predicate
  + shellquote: fix missing quotes for empty string
  + templatekw: fix {join(bookmarks, sep)} to always show associated bookmarks
  + transaction: disable hardlink backups (issue4546)
* Wed Feb  4 2015 develop7@develop7.info
- update to v3.3
  + commands
  * add: add back forgotten files even when not matching exactly (BC)
  * addremove: add back forgotten files (BC)
  * addremove: add support for the -S flag
  * addremove: print relative paths when called with -I/-X (BC)
  * addremove: support addremove with explicit paths in subrepos
  * backout: add --commit option
  * commit: abort if --addremove is specified, but fails
  * commit: remove reverse search for copy source when not in parent (issue4476)
  * commit: propagate --addremove to subrepos if -S is specified (issue3759)
  * graft: show more useful status information while grafting
  + core
  * bundles: do not overwrite existing backup bundles (BC)
  * osx: patch .pax.gz files in pkg bundles so they extract as root (issue4081)
  * revset: handle hidden linkrev for file missing for head (issue4490)
  * revset: allow rev(-1) to indicate null revision (BC)
  * revset: fix ancestors(null) to include null revision (issue4512)
  * subrepo: don't abort in add when non-hg subrepos are present (issue4513)
  * cmdserver: use given streams as pipe channels like other commands
  * extensions: only check compatibility against major and minor versions (BC)
  * https: support tls sni (server name indication) for https urls (issue3090)
  * ignore: resolve ignore files relative to repo root (issue4473) (BC)
  * linkrev: handle filtered linkrev with no visible children (issue4307)
  * linkrev: also adjust linkrev when bootstrapping annotate (issue4305)
  * linkrev: use the right manifest content when adjusting linrev (issue4499)
  * memctx: calculate manifest correctly with newly-removed files (issue4470)
  * memctx: fix manifest for removed files (issue4470)
  * obsstore: disable garbage collection during initialization (issue4456)
  * subrepo: support remove with explicit paths in subrepos
  * subrepo: add full revert support for git subrepos
  * subrepo: add partial diff support for git subrepos
  * subrepo: add status support for ignored files in git subrepos
  * win32: remove Mercurial.ini file from Inno Setup installer (issue4435)
  + hgweb
  * hgweb: allow viewing diffs against p1 or p2 for merge commits (issue3904)
  + extensions
  * color: add support for colorizing git subrepo diffs
  * color: add missing 'dim' in _effects
  * convert: on svn failure, note libsvn version (issue4043)
  * convert: replace revision references in messages if they are >= short hashes
  * convert: handle LookupError in mercurial_source.lookuprev()
  * extdiff: reintroduce backward compatibility with manual quoting of parameters
  * histedit: add a test to show that issue4251 is fixed (issue4251)
  * largefiles: fix commit of a directory with no largefile changes (issue4330)
  * largefiles: use 'default' path for pulling largefiles, not 'default-push'
  * largefiles: enable subrepo support for add, forget, remove
  * largefiles: show progress when checking standin hashes in outgoing changesets
  * mq: smarter handling of plain headers
  * patchbomb: don't honor whitespace and format-changing diffopts (BC)
  * rebase: show more useful status information while rebasing
  * rebase: ensure rebase revision remains visible (issue4504)
  * extdiff: avoid unexpected quoting arguments for external tools (issue4463)
  * highlight: ignore Unicode's extra linebreaks (issue4291)
  * record: don't honor format-changing diffopts (issue4459)
  * share: add option to share bookmarks
  * transplant: properly skip empty changeset (issue4423)
- provide cacerts.rc for all OS, not just >1130
* Fri Dec 19 2014 develop7@develop7.info
- update to v3.2.3
  * context: stop setting None for modified or added nodes
  * darwin: omit ignorable codepoints when normcase()ing a file path
  * encoding: add hfsignoreclean to clean out HFS-ignored characters
  * largefiles: don't actually remove largefiles in an addremove dry run
  * log: fix log -f slow path to actually follow history
  * log: fix log revset instability
  * manifest: disallow setting the node id of an entry to None
  * pathauditor: check for Windows shortname aliases
  * pathauditor: check for codepoints ignored on OS X
  * rebase: ignore negative state when updating back to original wc parent
  * update: add tests for untracked local file
  * update: don't overwrite untracked ignored files on update
* Tue Dec 16 2014 develop7@develop7.info
- properly replaced previously dropped mercurial-2.8-ssl.diff with cacerts.rc
* Mon Dec 15 2014 develop7@develop7.info
- update to v3.2.2
  * see changelog at http://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.2.2_.282014-12-01.29
* Sat Nov 15 2014 develop7@develop7.info
- update to 3.2.1
  * see changelog for v3.2.1 at http://mercurial.selenic.com/wiki/WhatsNew#Mercurial_3.2.1_.282014-11-11.29
- refreshed mercurial-locale-path-fix.patch
- dropped obsolete mercurial-2.8-ssl.diff
- dropped outdated contrib stuff from spec
* Sat Oct  4 2014 develop7@develop7.info
- update to v3.1.2
  * commit: catch changed exec bit on files from p1 (issue4382)
  * diff: document the nobinary option
  * dispatch: check shell alias again after loading extensions (issue4355)
  * dispatch: make "_checkshellalias" reusable regardless of adding aliases
  * help: fix typo in log examples
  * help: mention mode in hg log --removed help (issue4381)
  * hgweb: fail if an invalid command was supplied in url path (issue4071)
  * hgweb: refresh hgweb.repo on phase change (issue4061)
  * histedit: abort gracefully on --continue/--abort with no state
  * keepalive: fix how md5 is used
  * mq: examine "pushable" of already applied patch correctly
  * mq: pop correct patches when changing pushable-ness of already applied ones
  * mq: report correct numbers for changing "number of guarded, applied patches"
  * mq: use "mq.applied[i].name" instead of "mq.appliedname(i)" for safety
  * revset: add an optimised baseset.contains (issue4371)
  * templater: fix precedence of --style and --template options
* Mon Sep 15 2014 develop7@develop7.info
- update to v3.1.1
  Changes in v3.1:
  * backout: accept '--edit' like other commands creating new changeset
  * bash_completion: add -l|--list support for shelve
  * bookmarks: avoid deleting primary bookmarks on rebase
  * bookmarks: improve the bookmark help (issue4244)
  * branch: add debug message for branch cache write failure
  * bugzilla: stop trying to cache setup across hook invocation
  * build: initial support for in-tree autobuilding recipes
  * buildrpm: include release version in .tar.gz name
  * bundle2: add pushkey support
  * bundle2: fix bundle2 pulling all revs on empty pulls
  * commit: make commit message shown in text editor customizable by template
  * config: allow 'user' in .hgrc ui section (issue3169)
  * convert: detect removal of ".gitmodules" at git source revisions correctly
  * convert: drastically speed up git conversions
  * convert: mercurial source: convert global tags only - not local tags
  * convert: only consider shamap revisions converted if they still exists
  * convert: update the transplant, rebase and graft references in 'extra'
  * diff: add nobinary config to suppress git-style binary diffs
  * discovery: if a push would create a new head, mention the bookmark name if any
  * filemerge: add internal:tagmerge merge tool
  * filemerge: use 'basic' as the default of '[ui] mergemarkers' for safety
  * filemerge: use non-minimal conflict marker regions (BC)
  * gpg: accept '--edit' like other commands creating new changeset
  * graft: customize graft conflict markers (BC)
  * help: always show command help with -h (issue4240)
  * help: suggest keyword search when no topic is found
  * histedit: respect revsetalias entries (issue4311)
  * import: add --partial flag to create a changeset despite failed hunks
  * largefiles: avoid unnecessary creation of .hg/largefiles when opening lfdirstate
  * largefiles: include largefiles when doing log on a directory (issue4241)
  * largefiles: show also how many data entities are outgoing at "hg outgoing"
  * largefiles: use "normallookup", if "mtime" of standin is unset
  * log: allow revset for --follow to be lazily evaluated
  * log: do not use exact matcher for --patch --follow without file (issue4319)
  * log: make --patch --follow work inside a subdirectory
  * make: add a basic osx mpkg target
  * merge: add conflict marker formatter (BC)
  * merge: define conflict marker labels in filemerge()
  * mergetools.hgrc: add minimal configuration for editmerge
  * packaging: move output directory from build/ to packages/
  * pager: add attend-<command> option
  * patchbomb: includes series information in the header
  * pull: when remote supports it, pull phase data alongside changesets
  * purge: add options for deleting only files or only directories
  * push: use bundle2 to push phases when available
  * qfold: allow to specify '--message/'--logfile' and '--edit' at the same time
  * qimport: record imported revs incrementally (issue3874)
  * qrefresh: allow to specify '--message/'--logfile' and '--edit' at the same time
  * rebase: specify custom conflict marker labels for rebase (BC)
  * resolve: abort when not applicable (BC)
  * resolve: don't abort resolve -l even when no merge is in progress
  * resolve: print message when no unresolved files remain (issue4214)
  * resolve: print warning when no work performed (issue4208)
  * revset: maintain ordering when subtracting from a baseset (issue4289)
  * revset: optimize baseset.sub (issue4313)
  * setup: fixed for Pythons which don't have a CFLAGS
  * setup: make Xcode 5.1 check less specific
  * shelve: accept '--edit' like other commands creating new changeset
  * strip: drop -b/--backup option (BC)
  * strip: remove bookmarks after strip succeed (issue4295)
  * templatefilter: add splitlines function
  * templatekw: add 'currentbookmark' keyword to show current bookmark easily
  * templatekw: add 'subrepos' keyword to show updated subrepositories
  * templater: introduce startswith function
  * templater: introduce word function
  * templates: escape NUL bytes in jsonescape (issue4303)
  * update: introduce --tool for controlling the merge tool
  * update: show message when a bookmark is activated by update
  * update: specify custom conflict markers for update (BC)
  * update: when deactivating a bookmark, print a message
  * version: show enabled extensions (issue4209)
  * version: don't traceback if no extensions to list (issue4312)
  * vim: use try catch in vim plugin to avoid conflicts
  Changes in v3.1.1:
  * changectx: ancestor should only prefer merge.preferancestor if it is a revision
  * color: pass on key error for win32 (issue4298)
  * config: exit non zero on non-existent config option (issue4247)
  * context: call normal on the right object
  * debugobsolete: catch ValueError that may be raised by obsstore.create
  * discovery: prevent crash on unknown remote heads with old repo (issue4337)
  * graft: fix collision detection with origin revisions that are missing
  * help: add pad function to template help
  * help: only call doc() when it is callable
  * hgweb: avoid config object race with hgwebdir (issue4326)
  * histedit: preserve initial author on fold (issue4296)
  * import: show warning message for merge changesets
  * incoming: don't request heads that already are common
  * largefiles: don't override matchandpats for always matchers (issue4334)
  * largefiles: drop setting lfstatus in overridelog (issue4334)
  * largefiles: in overridelog, use non-lf matcher for patch generation (issue4334)
  * log: use correct phase info for parent field (issue4347)
  * merge: show the scary multiple ancestor hint for merges only, not for updates
  * obsstore.create: add a simple safeguard against cyclic markers
  * repoview: filter tags to non-existent nodes from blockers (issue4328)
  * repoview: fix typo in repoview.changelog
  * revset: bookmark revset interprets 'literal:' prefix correctly (issue4329)
  * unbundle: don't advance bookmarks (issue4322) (BC)
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Tue Jul 22 2014 develop7@develop7.info
- update to v 3.0.2
  * cmdutil: add copy-filtering support to duplicatecopies
  * hgweb: avoid initialization race (issue4280)
  * keyword: suppress keyword expansion for internal merge
  * match: make glob '**/' match the empty string
  * p4: accept changesets with no description (issue4282)
  * parsers.c: fix a couple of memory leaks
  * push: restore contents of HG_URL for hooks (issue4268)
  * rebase: fix bug that caused transitive copy records to disappear (issue4192)
  * repoview: do not crash when localtags refers to non existing revisions
  * resolve: keep wlock while resolving
  * revlog: hold a private reference to self._cache
  * revlog: make _chunkcache access atomic
* Sun Jun  8 2014 develop7@develop7.info
- update to version 3.0.1
  * alias: change return code of bad definition to 255
  * alias: fix loss of non-zero return code in command aliases
  * alias: handle shlex error in command aliases
  * bookmarks: properly align multi-byte characters
  * bugzilla: support Bugzilla 4.4.3+ API login token authentication (issue4257)
  * bundle2: fix bundle2 pulling all revs on empty pulls
  * bundle2: fix configuration name mismatch
  * changelog: ensure changelog._delaybuf is initialized
  * color: don't fail on error messages when no curses (issue4237)
  * exchange: propagate arguments to the _getbundleextrapart function
  * localrepo: prevent leak of transaction object (issue4258)
  * proxy: remove unneeded _set_hostport for compatibility with Python 2.7.7rc1
  * setup.py, make: avoid problems with outdated, existing hgext/__index__.py*
  * subrepo: avoid sanitizing ".hg/hgrc" in meta data area for non-hg subrepos
  * subrepo: invoke "_sanitize()" also after "git merge --ff"
  * subrepo: make "_sanitize()" take absolute path to the root of subrepo
  * subrepo: make "_sanitize()" work
  * subrepo: normalize path in the specific way for problematic encodings
  * templates: fix ifcontains against sets with length > 1 (issue4259)
  * win32: backout 1a9ebc83a74c
* Fri May  2 2014 develop7@develop7.info
- update to version 3.0
  * Core features
    + cat: support explicit paths in subrepos
    + cmdserver: allow starting server without repository
    + clone: abort if default destination has no meaningful name (BC)
    + clone: put streaming clones in a transaction
    + color: add debugcolor command (issue4094)
    + color: allow color keywords to be used directly in template
    + commands: add -T as alternative to --template
    + commands: hg debuginstall checks missing templates (issue4151)
    + commit: --edit/-e allows editing commit message supplied through other means
    + config: add initial implementation of --edit (with --global and --local flags)
    + debuginstall: add Python information to debuginstall output (issue4128)
    + demandimport: support HGDEMANDIMPORT=disable to disable demandimport
    + hgweb: add metadata to atom and rss feed entries
    + http: reuse authentication info after the first failed request (issue3567)
    + log: change implementation to use graphlog code
    + push: provide a hint when no paths are configured (issue3692)
    + require: provide a link to a wiki page as well as suggesting upgrade
    + revset: new implementation with incremental evaluation
    + revset: try to handle hyphenated symbols if lookup callback is available
    + revset: add 'only()' revset
    + sshpeer: only print out 'running ssh' messages in debug mode (BC)
    + template: add ifcontains template function
    + template: add pad function for padding output
    + template: add revset() template function
    + template: add shortest(node) template function
    + template: add flexible -T option
    + win32: improve the performance of win32.unlink() over CIFS
  * Extension features
    + blackbox: log events related to branch cache
    + convert: avoid updating tags when there is nothing new
    + convert: compare tags from all heads instead of just one
    + convert: replace old sha1s in the description
    + extensions: mark win32text deprecated
    + extensions: remove interhg
    + extensions: remove the inotify extension (BC)
    + histedit: select the lowest rev when looking for a root in a revset (BC)
    + journal: report parsing errors on recover/rollback (issue4172)
    + qimport: allow importing URLs
  * Fixes
    + backout: don't limit ancestry check to a single ancestor
    + backout: improve confusing 'cannot backout change on a different branch' abort
    + caches: invalidate store caches when lock is taken
    + cmdserver: forcibly use L channel to read password input (issue3161)
    + cmdserver: reload mq on each runcommand request to avoid corruption
    + diff: use second filename for --stat reporting on git patches (issue4221)
    + dirstate: report bad subdirectories as match.bad, not just a warning (BC)
    + extensions: use normpath to allow trailing '\' on Windows (issue4187)
    + fncache: clean up fncache during strips
    + largefiles: changed overridelog to work with graphlog
    + largefiles: don't prompt when one side of merge was changed but didn't change
    + largefiles: remove directories emptied after their files are moved (issue3515)
    + parsers: fail fast if Python has wrong minor version (issue4110)
    + phases: apply publishing enforcement for "serve" source
    + revlog: deal with chunk ranges over 2G on Windows (issue4215)
    + setup.py: fix C extension compilation issue with OS X 10.9 and Xcode 5.1
    + subrepo: check return code for git push (issue4223)
  * Experimental features
    + bundle2: experimental support for bundle2
    + merge: experimental implementation of bid merge
    + merge: tell when .ancestor picks one of multiple common ancestors heads
- removed mercurial-sle10-inotify-fixes.diff as upstream removed inotify extension
* Thu Mar 13 2014 develop7@develop7.info
- update to version 2.9.1
  * coal: hgweb style adds extra blank line in file view (issue4136)
  * hg.openpath: use url.islocal to tell if the path is local (issue3624)
  * hgweb: hack around mimetypes encoding thinko (issue4160)
  * hooks: only disable/re-enable demandimport when it's already enabled
  * merge: add "other" file node in the merge state file
  * merge: audit the right destination file when merging with dir rename
  * merge: don't overwrite file untracked after remove, abort with 'untracked files'
  * merge: record the "other" node in merge state
  * pathencode: eliminate signed integer warnings
  * pull: close peer repo on completion (issue2491) (issue2797)
  * purge: avoid duplicate output for --print (issue4092)
  * rebase: do not try to reactivate deleted divergent bookmark
  * resolve: use "other" changeset from merge state (issue4163)
  * verify: do not prevent verify repository containing hidden changesets
* Mon Feb 17 2014 develop7@develop7.info
- update to version 2.9
  * aliases: make "_checkshellalias()" invoke "findcmd()" with "strict=True"
  * backout: add a message after backout that need manual commit
  * backout: avoid update on simple case
  * bash_completion: add completion for deleting a shelve
  * bash_completion: add global support for -B|--bookmark
  * bash_completion: add global support for -b|--branch
  * bisect: --command without --noupdate should flag the parent rev it tested
  * bookmarks: allow push -B to create a new remote head (Bts:issue2372)
  * branchmap: cache open/closed branch head information
  * cat: increase perf when catting single files
  * changectx: increase perf of walk function
  * clone: do not turn hidden changeset public on publishing clone (Bts:issue3935)
  * convert: use branchmap to change default branch in destination (Bts:issue3469)
  * date: allow %%z in format (Bts:issue4040)
  * diff: search beyond ancestor when detecting renames
  * hgweb: infinite scroll support for coal, gitweb, and monoblue styles
  * merge: consider successor changesets for a bare update
  * patch: add support for git delta hunks
  * phase: properly compute ancestors of --rev on push (Bts:issue3786)
  * rebase: abort cleanly when we encounter a damaged rebasestate (Bts:issue4155)
  * rebase: do not crash in panic when cwd disapear in the process (Bts:issue4121)
  * record: --user/-u now works with record when ui.username not set (Bts:issue3857)
  * record: re-enable whitespace-ignoring options
  * relink: abort earlier when on different devices (Bts:issue3916)
  * strip: add faster revlog strip computation
  * subrepo: check phase of state in each subrepositories before committing
  * subrepo: make it possible to update to hidden subrepo revisions
  * subsettable: move from repoview to branchmap, the only place it's used
  * templater: selecting a style with no templates does not crash (Bts:issue4140)
  * update: consider successor changesets when moving active bookmark
  * url: added authuri when login information is requested (Bts:issue3209)
* Thu Jan  9 2014 wr@rosenauer.org
- update to version 2.8.2
  * fileset, revset: do not use global parser object for thread safety
  * hgweb: avoid initialization race (issue3953)
  * mpatch: rewrite pointer overflow checks
* Fri Dec 13 2013 wr@rosenauer.org
- update to version 2.8.1
  * bookmarks: consider successor changesets when moving bookmark (issue4015)
  * contrib: don't mention obsolete graphlog extension in mercurial.ini
  * contrib: promote strip extension over MQ in sample.hgrc
  * contrib: stop mentioning obsolete graphlog extension in sample.hgrc
  * convert: fix svn crash when svn.ra.get_log calls back with orig_paths=None
  * help: fix backwards bisect help example
  * help: use progress instead of mq as in 'hg help config' example
  * hgk: fix tag list parser (issue4101)
  * hgweb: ignore non numeric "revcount" parameter values (issue4091)
  * histedit: hold wlock and lock while in progress
  * largefiles: cache largefiles for update, also without printmessage
  * largefiles: don't crash on 'local renamed directory' actions
  * merge: move forgets to the beginning of the action list
  * minirst: do not interpret a directive as a literal block
  * minirst: find admonitions before pruning comments and adding margins
  * obsolete: stop doing membership test on list
  * parse_index2: fix crash on bad argument type (issue4110)
  * phase: better error message when --force is needed
  * rebase: fix rebase aborts when 'tip-1' is public (issue4082)
  * rebase: fix working copy location after a --collapse (issue4080)
  * share: fix unshare calling wrong repo.init() method
  * shelve: fix bad argument interaction with largefiles (issue4111)
  * shelve: unshelve using an unfiltered repository
  * strip: fix last unprotected mq reference (issue4097)
  * strip: hold wlock for entire duration
  * subrepo: sanitize non-hg subrepos
  * templater: fix escaping in nested string literals (issue4102)
  * templater: makes branches work correctly with stringify (issue4108)
  * templater: only recursively evaluate string literals as templates (issue4103)
  * unshelve: add tests for unknown files
  * unshelve: don't commit unknown files during unshelve (issue4113)
  * util: url keeps backslash in paths
  * util: warn when adding paths ending with \
* Sun Nov 24 2013 wr@rosenauer.org
- update to version 2.8
  Core features
    hgweb: add revset syntax support to search
    hgweb: always run search when a query is entered (BC)
    hgweb (paper theme): add infinite scrolling to graph
    hgweb: show full date in rfc822 format in tooltips at shortlog page
    proxy: allow wildcards in the no proxy list (issue1821)
    pull: for pull --update with failed update, print hint if any
    rebase: preserve working directory parent (BC)
    sslutil: add a config knob to support TLS (default) or SSLv23 (BC) (issue4038)
    templatefilters: add short format for age formatting
    templater: support using templates with non-standard names from map file
    update: add error message for dirty non-linear update with no rev
    addremove: don't do full walks
    log: make file log slow path usable on huge repos
    subrepo: let the user choose to merge, keep local or keep remote subrepo revisions
  Extension features
    convert-internals: introduce hg.revs to replace hg.startrev and --rev with a revset
    convert-internals: update source shamap when using filemap, just as when not using filemap
    factotum: clean up keychain for multiple hg repository authentication
    histedit: abort if there are multiple roots in "--outgoing" revisions
    mq: extract strip function as its standalone extension (issue3824)
    mq: look for modified subrepos when checking for local changes
    rebase: remove bailifchanged check from pullrebase (BC)
    shelve: add a shelve extension to save/restore working changes
  Fixes
    pager: honour internal aliases
    patch: ensure valid git diffs if source/destination file is missing (issue4046)
    patch: Fix nullid for binary git diffs (issue4054)
    progress: stop getting stuck in a nested topic during a long inner step
    rebase: handle bookmarks matching revset function names (issue3950)
    rebase: preserve active bookmark when not at head (issue3813)
    rebase: preserve metadata from grafts of changes (issue4001)
    rebase: fix selection of base used when rebasing merge (issue4041)
    ui: send password prompts to stderr again (issue4056)
- recover 11.4 support by requiring docutils instead of python-docutils
- rebased mercurial-2.6.3-ssl.diff to mercurial-2.8-ssl.diff
* Thu Oct 24 2013 speilicke@suse.com
- Drop dependency on python-roman, python-docutils' module docutils.utils.roman
  should be sufficient
- Drop checks for obsolete distributions
- Drop dependency on rcs, it doesn't seem to be used anywhere and was
  added in 2006
- Depend on openssl-certs if %%sles_version is defined (for our IBS friends)
- Require python-docutils instead of the obsolete docutils
* Wed Oct 23 2013 ohering@suse.de
- Refresh mercurial-docutils-compat.diff to fix build in sles11sp3
* Thu Oct 10 2013 wr@rosenauer.org
- update to version 2.7.2
  * Regularly scheduled bugfix release. This fixes significant
    regressions from 2.7 in push/pull performance and SSL negotiation
  bundle: fix performance regression when bundling file changes (issue4031)
  generaldelta: initialize basecache properly
  help: use full name of extensions to look up them for keyword search
  histedit: abort if there are multiple roots in "--outgoing" revisions
  histedit: add more detailed help about "--outgoing"
  histedit: suggest "histedit --abort" for inconsistent histedit state
  httpclient: apply upstream revision da7579b034a4 to fix SSL problems (issue4038)
  rebase: catch RepoLookupError at restoring rebase state for abort/continue
  rebase: catch RepoLookupError at restoring rebase state for summary
  repoview: have unfilteredpropertycache using the underlying cache
  repoview: make propertycache.setcache compatible with repoview
  revset: fix wrong keyword() behaviour for strings with spaces
  sslutil: backed out changeset 074bd02352c0 (issue4038)
  strip: set current bookmark to None if stripped
* Wed Sep  4 2013 wr@rosenauer.org
- update to version 2.7.1
  * shrink-revlog.py was removed from distribution
  * no upstream changelog available
- update to version 2.7.0
  This release contains an important fix for a merge ancestor
  calculation regression in the 2.6 series.
  ancestor: decrement ninteresting correctly (issue3984)
  bookmarks: allow bookmark command to take multiple arguments
  bookmarks: pull --update updates to active bookmark if it moved (issue4007)
  bookmarks: update only proper bookmarks on push -r/-B (issue 3973)
  changegroup: fix fastpath during commit
  checklink: work around sshfs brain-damage (issue3636)
  churn: split email aliases from the right
  commands: add checks for unfinished operations (issue3955)
  commit: enable --secret option
  convert: catch empty origpaths in svn gettags (issue3941)
  convert: fix bad conversion of copies when hg.startrev is specified
  convert: handle changeset sorting errors without traceback (issue3961)
  hgweb: fix incorrect way to count revisions in log (issue3977)
  hgweb: run search instead of showing wrong error for ambigious identifier
  histedit: don't clobber working copy on --abort if not on histedit cset
  histedit: refuse to edit history that contains merges (issue3962)
  import: cut commit messages at --- unconditionally (issue2148)
  largefiles: overridematch() should replace the file path instead of extending (issue3934)
  log: add a log style that is default+phase (issue3436)
  paper: add line wrapping switch to file source view
  paper: code selection without line numbers in file source view
  paper: highlight line which is linked to in source view
  progress: respect HGPLAIN
  rebase: allow aborting when descendants detected
  rebase: continue abort without strip for immutable csets (issue3997)
  rebase: don't clobber wd on --abort when we've updated away (issue4009)
  revert: make backup when unforgetting a file (issue3423)
  revlog: handle hidden revs in _partialmatch (issue3979)
  rollback: mark as deprecated
  splicemap: improve error handling when parsing (issue2084)
  splicemap: support paths with spaces in splicemap (issue3844)
  sslutil: force SSLv3 on Python 2.6 and later (issue3905)
  summary: augment output with info from extensions
  templater: add strip function with chars as an extra argument
  log: show style list when unknown style specified
  tip: deprecate the tip command
  update: add tracking of interrupted updates (issue3113)
  worker: check problem state correctly (issue3982)
  worker: properly report errors from worker processes (issue3982)
* Thu Aug 29 2013 wr@rosenauer.org
- bring back cacerts.rc for distributions older than 13.1
* Mon Aug 26 2013 lnussel@suse.de
- don't pass ca_certs to make python use the system's built in path
  (bnc#836739) (mercurial-2.6.3-ssl.diff) starting from 13.1
* Tue Jul 16 2013 wr@rosenauer.org
- update to version 2.6.3
  This is a regularly-scheduled bugfix release.
  * commit: amending with --close-branch (issue3445)
  * doc: make it easier to read how to enable extensions
  * doc: reword "config file" to "configuration file"
  * docs: change description to synopsis in hgrc.5
  * histedit: raise ImportError when demandloading is enabled
  * pathencode: fix hashmangle short dir limit (issue3958)
  * update: remove .hg/graftstate on clean (issue3970)
* Sun Jun 16 2013 wr@rosenauer.org
- update to version 2.6.2
  This is a regularly-scheduled bugfix release.
  * amend: complain more comprehensibly about subrepos
  * blackbox: fix blackbox causing exceptions in tests
  * blackbox: fix recording exit codes (issue3938)
  * dirstate: don't overnormalize for ui.slash
  * graft: refuse to commit an interrupted graft (issue3667)
  * help: fix role/option confusion in RST
  * help: stop documentation markup appearing in generated help
* Wed May 22 2013 pcerny@suse.com
- update to version 2.6.1 (2013-05-14)
  * convert
    fix bug of wrong CVS path parsing without port number (issue3678)
  * help/config
    note 64-bit Windows registry key used with 32-bit Python
  * hfs+
    rewrite percent-escaper (issue3918)
  * hgignore
    fix regression with hgignore directory matches (issue3921)
  * highlight
    fix page layout with empty first and last lines
  * largefiles
    check existence of the file with case awareness of the filesystem
    check unknown files with case awareness of the filesystem
  * pathencode
    grow buffers to increase safety margin
  * revert
    ensure that copies and renames are honored (issue3920)
  * subrepo
    open files in 'rb' mode to read exact data in (issue3926)
  * windows
    check target type before actual unlinking to follow POSIX semantics
- update to 2.6 (2013-05-01)
  * addremove
    improve performance
  * amend
    support amending merge changesets (issue3778)
  * ancestor
    a new algorithm that is faster for nodes near tip
  * annotate
    increase refcount of each revision correctly (issue3841)
  * applyupdates
    assign variable before we try to use it (issue3855)
  * archive
    raise error.Abort if the file pattern matches no files
  * bash_completion
    allow remove to complete normal files
  * blackbox
    new extension
  * bookmarks
    don't allow integers as bookmark/branch/tag names
    allow (re-)activating a bookmark on the current changeset
    allow moving a bookmark forward to a descendant
    moving the active bookmark deactivates it
    fix bug that activated a bookmark even with -r passed
    resolve divergent bookmark when moving across a branch
    resolve divergent bookmarks when moving active bookmark forward
  * commit
    allow closing "non-head" changesets
    show active bookmark in commit editor helper text
  * config
    discard "%%unset" values defined in the other files read in previously
  * convert/git
    catch errors from modern git-ls-remote (issue3428)
  * convert
    add closesort algorithm to mercurial sources
  * dates
    support 'today' and 'yesterday' in parsedate (issue3764)
  * destroyed
    invalidate phraserevs cache in all case (issue3858)
  * diff
    fix binary file removals in git mode
  * dirstate
    performance improvements
  * dispatch
    exit with status 1 for an InterventionRequired exception (BC)
    print 'abort:' when a pre-command hook fails (BC)
  * export
    clobber files with -o (BC) (issue3652)
    export working directory parent by default
    show 'Date' header in a format that also is readable for humans
  * extensions
    obsolete and remove interhg extension
  * filesets
    add eol predicate
  * grep
    use re2 if possible
  * hgk
    add support for phases
    don't use fixed format for dates
    update backgroud colour when Ttk is available
  * hgweb
    generate HTML documentation
    teach archive how to download a specific directory or file
  * histedit
    allow "-" as a command file
    handle multiple spaces between action and hash (issue3893)
    make "hg histedit" sensitive to branch in URL
    properly handle --continue on empty fold
    support editing of the first commit (issue3767)
  * httppeer
    avoid large dumps when we don't see an hgweb repo
  * icasefs
    rewrite case-folding collision detection (issue3452)
  * import
    don't rollback on failed import --exact (issue3616)
  * largefiles
    don't cache largefiles for pulled heads by default
    improve reuse of HTTP connections
    introduce lfpull command for pulling missing largefiles
    introduce pull --lfrev option
    introduce pulled() revset expression for use in --lfrev
    quiet (and document) undefined name errors (issue3886)
    stat all largefiles in one batch before downloading
    use repo.wwrite for writing standins (issue3909)
  * log
    fix behavior with empty repositories (issue3497)
  * merge
    apply non-interactive working dir updates in parallel
  * mergetools
    avoid losing the merged version with meld
    vimdiff issues a warning explaining how to abort
  * mq
    comply with filtering when injecting fake tags (issue3812)
    do not inherit settings form base repo in mqrepo (Fixes issue2358)
  * outgoing
    fix possible filtering crash in outgoing (issue3814)
  * pager
    catch ctrl-c on exit (issue3834)
  * date
    understand "now" as a shortcut for the current time
  * parsers
    a C implementation of the new ancestors algorithm
  * pull
    list bookmarks before pulling changesets (issue3873)
  * push
    make locking of source optional (issue3684)
  * rebase
    check no-op before checking phase (issue3891)
    fix --collapse when a file was added then removed
  * record
    abort on malformed patches instead of crashing
  * revset
    change ancestor to accept 0 or more arguments (issue3750)
    don't abort when regex to tag() matches nothing (issue3850)
  * sadclown
    another test failure eluded bos
  * scheme
    don't crash on invalid URLs
  * scmutil
    rewrite dirs in C, use if available
  * setup
    make error message for missing Python headers more helpful
  * smtp
    use 465 as default port for SMTPS
    verify the certificate of the SMTP server for STARTTLS/SMTPS
  * sshpeer
    store subprocess so it cleans up correctly
  * sslutil
    abort if peer certificate is not verified for secure use
  * subrepo
    clone of git sub-repository creates incorrect git branch (issue3870)
    do not push mercurial subrepos whose store is clean
    fix exception on revert when "all" option is omitted
  * summary
    make "incoming" information sensitive to branch in URL (issue3830)
    make "outgoing" information sensitive to branch in URL (issue3829)
    show active bookmark even if not at current changeset
  * tags
    update tag type only if tag node is updated (issue3911)
  * templatekw
    add default styles for hybrid types (issue3887)
  * templater
    add get() function to access dict element (e.g. extra)
  * unionrepo
    read-only operations on a union of two localrepos
  * win32
    use explicit path to "python.exe" only if it exists
* Sat Apr  6 2013 toms@opensuse.org
- update to version 2.5.4
  fixes an urgent regression in merging with subrepos introduced in 2.5.
  See http://mercurial.selenic.com/wiki/WhatsNew for versions
  2.5.2 and 2.5.3
- SPEC file:
  Provides contained a typo. Should be %%{version} instead of just {verison}
  (without %%)
* Mon Feb 11 2013 p.drouand@gmail.com
- update to version 2.5.1
  (bugfix release)
    hgk: support the old way of getting the current Ttk theme (issue3808)
    hgweb.cgi: fix internal WSGI emulation (issue3804)
    hgweb: make 'summary' work with hidden changesets (issue3810)
    incoming: fix incoming when a local head is remotely filtered (issue3805)
    largefiles: don't crash when trying to find default dest for url without path
    rebase: derive node from target rev (issue3802)
- update to version 2.5.0
  * Core features
    branchmap: improved performances
    bundle: add revset expression to show bundle contents (issue3487)
    dirstate: implement unix statfiles in C
    hgweb: add (Atom) subscribe links to the repository index
    hgweb: add "URL breadcrumbs"
    hgweb: add branches RSS and Atom feeds
    hgweb: secret changeset are excluded from html view (3614 )
    serve: use chunked encoding in hgweb responses
    pathencode: implement both basic and hashed encoding in C
    subrepo: append subrepo path to subrepo error messages
    validate: check for spurious incoming filelog entries
    hgweb: allow hgweb's archive to recurse into subrepos
  * Changeset Evolution
    hidden changesets are now properly ignored by all commands
    a global --hidden flag is added to give access to hidden changesets
    rewriting a changeset but not its descendants is now allowed; this leaves
    unstable changeset behind
    we now detect *divergent* changesets. The third and last kind of obsolescence
    related troubles. divergent() revset is added
    a troubled() revset have been added
    branchmap for of *visible* and *served* changeset are now cached on disk.
    This is a major performance improvements
    performance improvements of most evolution related algorithm
  * Extension features
    color: add template label function
    convert: add config option to use the local time zone
    convert: add support for converting git submodule (issue3528)
    hgk: use Ttk instead of plain Tk
    inotify: don't fall over just because of a dangling symlink
    largefiles: fix revert removing a largefile from a merge
    largefiles: fix update from a merge with removed files
    largefiles: make log match largefiles in the non-standin location too
    largefiles: make update with backup files in .hglf slightly less broken
    largefiles: rename 'admin' to more descriptive 'lfstoredir
    rebase: performance improvements
    rebase: rebase set with multiple roots are now handled by the --rev option
    record: use patch.diffopts to account for user diffopts
    share: always set default path to work with subrepos (issue3518)
    zsh_completion: add completion of branch names
  * Fixes
    commands: 'hg bookmark NAME' should work even with ui.strict=True
    copies: do not track backward copies, only renames (issue3739)
    destroyed: keep the filecache in sync with __dict__ (issue3335, issue3693, issue3743)
    grep: don't search past the end of the searched string
    hgweb: properly returns 404 for unknown revision (instead of 500)
    histedit: proper phase conservation (issue3724)
    histedit: prevents obsolescence cycle (issue3681)
    hook: disable demandimport before importing hooks
    mq: don't fail when removing a patch without patch file from series file
    mq: fix qpop of working directory parent patch when not at qtip
    zeroconf: use port from server instead of picking port from config (issue3746)
    update: update to current bookmark if it moved out from under us (issue3682)
    bookmarks: show active bookmark even if not at working dir
    largefiles: let wirestore._stat return stats as expected by remotestore verify
    largefiles: adapt verify to batched remote statlfile (issue3780)
    largefiles: don't allow corruption to propagate after detection
    largefiles: don't verify largefile hashes on servers when processing statlfile
    largefiles: allow use of urls with #revision
    largefiles: fix commit when using relative paths from subdirectory
    largefiles: fix cat when using relative paths from subdirectory
    histedit: prevent parent guessed via --outgoing from being a revset (issue3770)
    rebase: delete divergent bookmarks on destination (issue3685)
    hgwebdir: use web.prefix when creating url breadcrumbs (issue3790)
    subrepo: allow skipping courtesy phase sync (issue3781)
    merge: .hgsubstate is special as merge destination, not as merge source
    merge: improved handling of symlinks
* Fri Jan 25 2013 douglarek@outlook.com
- update to version 2.4.2
  (bugfix release)
    amend: invalidate dirstate in case of failure (issue3670)
    amend: prevent loss of bookmark on failed amend
    bookmarks: fix head selection for merge with two bookmarked heads
    bundlerepo: don't return the peer without bundlerepo from getremotechanges
    dirstate: don't rename branch file if writing it failed
    dirstate: remove obsolete comment from setbranch
    hgweb: avoid generator exhaustion with branches
    hgweb: fix iterator reuse in atom feed generation
    hgwebdir: honor web.templates and web.static for static files (issue3734)
    largefiles revert: update lfdirstate with result from first cleanliness check
    largefiles status: update lfdirstate with result from cleanliness check
    largefiles: commit directories that only contain largefiles (issue3548)
    largefiles: don't walk through all ignored files
    paper: sanity-check page feed links
    scmutil: don't try to match modes on filesystems without modes (issue3740)
    zeroconf: use port from server instead of picking port from config (issue3746)
* Thu Dec 27 2012 wr@rosenauer.org
- update to version 2.4.1
  (bugfix release)
    amend: force editor only if old message is reused (issue3698)
    grep: don't search past the end of the searched string
    hooks: be even more forgiven of non-fd descriptors (issue3711)
    hooks: delay I/O redirection until we actually run a hook (issue3711)
    phases: fix missing "error" module import (issue3707)
    rebase: fix pull --rev options clashing with --rebase (issue3619)
    subrepo: add argument to "diff()" to pass "ui" of caller side (issue3712) (API)
    update: allow update to existing branches with invalid names (issue3710)
    util: make chunkbuffer non-quadratic on Windows
* Sat Nov 10 2012 wr@rosenauer.org
- update to version 2.4
  * Core features
    amend: support for ChangesetEvolution if enabled
    bookmarks: deactivate current bookmark if no name is given
    bookmarks: teach the -r option to use revsets
    bookmarks: disallow bookmarks named 'tip', '.', or 'null'
    clone: substantial speedup to clone on repo with a lots of
    heads (issue3378)
    clone: activate bookmark specified with --updaterev
    clone: update to @ bookmark if it exists
    log: substantial speedup for untracked files (issue1340)
    revsets: add branchpoint() function
    resolve: commit the changes after each item resolve (issue3638)
    subrepo, hghave: use "svn --version --quiet" to determine version number
    subrepo: setting LC_MESSAGES only works if LC_ALL is empty or unset
    templatefilters: add parameterized date method
    templatefilters: add parameterized fill function
    templatefilters: avoid traceback caused by bogus date input (issue3344)
    templatekw: add p1rev, p1node, p2rev, p2node keywords
    templatekw: add parent1, parent1node, parent2, parent2node keywords
    templater: abort when a template filter raises an exception (issue2987)
    templater: add if/ifeq conditionals
    templater: add sub() function
    templating: make new-style templating features work with command line lists
    bookmarks: take ChangesetEvolution into account when updating (issue3561)
    speedup various operation related to ChangesetEvolution
    add detection of changeset bumped by ChangesetEvolution
  * Extension features
    color: add additional changeset.phase label to log.changeset and log.parent
    color: enabled color support for export command (issue1507)
    color: support for all grep fields
    contrib: add a commit synthesizer for reproducing scaling problems
    histedit: refuse to edit public changeset
    histedit: replaces patching logic by merges
    histedit: support for ChangesetEvolution if enabled
    largefiles: always create the cache and standin directories when cloning
    largefiles: distinguish "no remote repo" from "no files to upload" (issue3651)
    largefiles: fix a traceback in lfconvert if a largefile is missing (issue3519)
    mq: improve qqueue message with patches applied (issue3036)
    mq: update bookmarks during qrefresh
    notify: support revset selection for subscriptions
    rebase: support for ChangesetEvolution if enabled
    record: checks for valid username before starting recording process (issue3456)
    record: fix display of non-ASCII names in chunk selection
  * Bugfixes
* Fri Oct  5 2012 wr@rosenauer.org
- update to version 2.3.2
  * bugfix release
    http://mercurial.selenic.com/wiki/WhatsNew
* Fri Sep  7 2012 toms@opensuse.org
- update to version 2.3.1
  http://mercurial.selenic.com/wiki/WhatsNew
- Spec file: fixed files-attr-not-set warning
* Mon Jul 30 2012 wr@rosenauer.org
- update to version 2.2.3
  * bugfix release
    http://mercurial.selenic.com/wiki/WhatsNew
* Thu Jun 14 2012 wr@rosenauer.org
- update to version 2.2.2
  * bugfix release
    http://mercurial.selenic.com/wiki/WhatsNew
- buildrequire python-roman for 12.2 and higher
* Wed May 16 2012 wr@rosenauer.org
- update to version 2.2.1
  * fix significant memory leak in hgweb
  * a few other bugfixes
- changes in version 2.2
  * feature release
  * new safe '--amend' option for commit using our new phases
    infrastructure
* Sun Apr 22 2012 wr@rosenauer.org
- update to version 2.1.2
  * bugfix release
    http://mercurial.selenic.com/wiki/WhatsNew
* Mon Mar  5 2012 wr@rosenauer.org
- update to version 2.1.1
  * bugfix release
    http://mercurial.selenic.com/wiki/WhatsNew
* Tue Feb  7 2012 wr@rosenauer.org
- update to version 2.1
  * feature and bugfix release
* Thu Jan 19 2012 wr@rosenauer.org
- update to version 2.0.2
  * bugfix release
- changes in version 2.0
  Major features
  * New core graft command (similar to transplant extension)
  * New largefiles extension
  Core changes
  * commit: abort when there are uncommitted subrepos, use the -S
    option to recurse
  * help: most commands now have usage examples with help -v
  * import: add --edit switch
  * revset: add more keywords for bisection
  * revert: introduce short option -C for --no-backup
  * log: add new 'bisect' style that prints the bisection status
  * hgweb: add a "web/logoimg" setting to customize the web logo
    image
  * subrepo: pull revisions on demand when archiving hg subrepos
  Extension changes
  * color: add styles for tags
  * convert: added bookmarks support in filemap
  * eol: add new eol.fix-trailing-newline setting
  * eol: eol.only-consistent can now be specified in .hgeol
  * export: add %%m to file format string (first line of the commit
    message)
  * mq: make qqueue print current queue name
  * rebase: add --edit switch
  * rebase: add --rev option to rebase
  * rebase: allow rebase on ancestor
  * share: introduce unshare command
  * transplant: add --edit option
  Bugfixes
* Fri Oct 21 2011 suse@ammler.ch
- upstream update 1.9.3
  * setup: build inotify for sys.platform='linux*'
  * bundlerepo: add argument check before unlink
  * hgweb: properly check for bookmarks when drawing graph
  * http: handle push of bundles > 2 GB again (issue3017)
  * keyword: preserve file mode when overwriting
  * osutil: avoid accidentally destroying the True object in isgui (issue2937)
  * patch: correctly handle non-tabular Subject: line
  * patch: handle 'gitpatches' being empty, but not none
  * record: use command wrapper properly for qnew/qrefresh (issue3001)
  * setdiscovery: fix hang when #heads>200 (issue2971)
  * ui: also swap sys.stdout with self.fout in _readline
  * ui: write traceback to self.ferr
  * url: Remove the proxy env variables only when needed (issue2451)
  * url: parse fragments first (issue2997)
  * util: fix crash converting an invalid future date to string
  * util: wrap lines with multi-byte characters correctly (issue2943)
* Tue Aug 30 2011 suse@ammler.ch
- upstream update 1.9.2
  * commands: clarify that 'hg heads foo' shows heads on branch foo
  * dispatch: don't rewrap aliases that have the same definition
  * graphlog: attempt to fix index overrun (issue2912)
  * http: pass user to readauthforuri() (fix 4a43e23b8c55)
  * http: strip credentials from urllib2 manager URIs (issue2885)
  * parsers: avoid pointer aliasing
  * subrepo: fix cloning of repos from urls without slash after host (issue2970)
  * ui: pass ' ' to raw_input when prompting
  * url: really handle urls of the form file:///c:/foo/bar/ correctly
- changes in version 1.9.1
  * dispatch: make sure global options on the command line take precedence
  * eol: ignore IOError from deleted files in commitctx
  * hgcia: set default value of strip to -1 (issue2891)
  * hgweb: do not ignore [auth] if url has a username (issue2822)
  * hgweb: handle 'baseurl' configurations with leading slash (issue2934)
  * hgweb: raw file mimetype guessing configurable, off by default (BC) (issue2923)
  * httpclient: import ca33b88d143c from py-nonblocking-http (issue2932)
  * patch: fix parsing patch files containing CRs not followed by LFs
  * rebase: block collapse with keepbranches on multiple named branches (issue2112)
  * rebase: reset bookmarks (issue2265 and issue2873)
  * revert: restore check for uncommitted merge (issue2915) (BC)
  * revsets: catch type error on tip^p1(tip) (issue2884)
  * revsets: do the right thing with x^:y (issue2884)
  * subrepo: handle adding svn subrepo with a svn:external file in it (issue2931)
  * subrepo: use working copy of .hgsub to filter status (issue2901)
  * url: store and assume the query part of an url is in escaped form (issue2921)
  * util: rename the util.localpath that uses url to urllocalpath (issue2875)
  * verify: filter messages about missing null manifests (issue2900)
  * web: output a correct date in short format (issue2902)
- optional tests
* Mon Jul 11 2011 saschpe@suse.de
- Spec file cleanup:
  * Fixed several rpmlint warnings (macros in comments, exec-bits)
  * Check for SUSE before using SUSE-specific stuff, fixes build on
    Fedora, Mandriva
  * Don't use --record-rpm and drop perl dependency
  * Drop gcc dependency, already pulled through python-devel
  * Drop unused asciidoc,sgml-skel,xmlto dependencies
  * Much simpler lang package generation (no shell scripts involved)
  * Run fdupes on %%{buildroot}%%{_prefix} to catch all dupes
- Added mercurial-locale-path-fix.patch to properly load locales
* Mon Jul  4 2011 ammler@openttdcoop.org
- update to version 1.9
  * New fileset file matching support
  * Improved remote changeset discovery
  * New command server mode to improve application integration
  * Experimental generaldelta storage scheme
  * Experimental new http client library
  - Command changes
  * HGPLAIN: allow exceptions to plain mode, like i18n, via HGPLAINEXCEPT
  * manifest: add new option --all
  * aliases: add positional arguments to non-shell aliases
  * add: introduce a warning message for non-portable filenames (Bts:issue2756)
  * add: notify when adding a file that would cause a case-folding collision
  * bisect: new command to extend the bisect range (Bts:issue2690)
  * bookmarks: allow deactivating current bookmark with -i
  * bundle: update current bookmark to most recent revision on current branch
  * diff: make diff -c aware of revision sets
  * help: add -c/--command flag to only show command help (Bts:issue2799)
  * help: add -e/--extension switch to display extension help text
  * help: move hgignore man page into built-in help (Bts:issue2769)
  * http: correctly handle redirects from http to https
  * identify: list bookmarks for remote repositories
  * import: add --bypass option
  * paths: Add support for -q/--quiet
  * pushkey: add hooks for pushkey/listkeys
  * revset: add aliases
  * revset: add ^ and ~ operators from parentrevspec extension
  * revset: add a revset command to get bisect state
  * revset: add desc(string) to search in commit messages
  * revset: add follow(filename) to follow a filename's history across copies
  * revset: introduce filelog() to emulate log's fast path
  * revset: add a last() function
  - Web changes
  * add bookmarks listing to raw style and summary pages
  * support alternate logo url
  * add base link to file log for paper and coal styles (Bts:issue2452)
  * paper, coal: display diffstat on the changeset page
  * elapsed time calculation dynamic (javascript)
  * provide diffstat and summary on the changeset page
  - Extension changes
  * hgcia: handle URL like in notify (Bts:issue2406)
  * rebase: add -m/--message to rebase --collapse (Bts:issue2389)
  * Updating hgext.extdiff to use revsets
  * bash_completion: enable alias auto-complete
  * bugzilla: add XMLRPC interface
  * color: add support for terminfo-based attributes and color
  * convert/mtn: add support for using monotone's "automate stdio" when available
  * convert/svn: stop using svn bindings when pushing to svn
  * convert: add bookmark support for hg and git backends
  * convert: add svnrev, svnpath and svnuuid template keywords
  * extdiff: add repository root as a variable
  * graphlog: support more log command features with revsets
  * keyword: convert a verbatim block to a field list
  * keyword: offer additional datefilters when the extension is enabled
  * mq: add a 'mq()' revset predicate that returns applied mq csets
  * notify: send changesets on 'outgoing' hook, updated doc
  * progress: add speed format
  * rebase: add --tool argument for specifying merge tool
  * rebase: allow for rebasing descendants onto ancestors on different named branches
  * record: add an option to backup all wc modifications
  * record: add qrefresh -i/--interactive
  * record: add white space diff options
  * record: alias qrecord to qnew -i/--interactive
  - Bug fixes
  * bookmarks: allow create/move bookmark without making it current (Bts:issue2788)
  * bookmarks: do not forward merged bookmark (Bts:issue1877)
  * changegroup: do not count closed new heads (Bts:issue2697)
  * config: handle comment lines in continuations (Bts:issue2854)
  * dispatch: propagate ui command options to the local ui (Bts:issue2523)
  * eol: make the hook check all new heads, not only tip (Bts:issue2666)
  * grep: don't print data from binary files for matches (Bts:issue2614)
  * http: report unexpected unparsable push responses (Bts:issue2777)
  * httprepo: handle large lengths by bypassing the len() operator
  * httprepo: long arguments support (Bts:issue2126)
  * httprepo: proper handling of invalid responses without content-type (Bts:issue2019)
  * httprepo: send URL redirection notices to stderr (Bts:issue2828)
  * localrepo: don't add deleted files to list of modified/added files (Bts:issue2761)
  * localrepo: ignore tags to unknown nodes (Bts:issue2750)
  * merge: drop resolve state for mergers with identical contents (Bts:issue2680)
  * patch: do not patch unknown files (Bts:issue752)
  * path_auditor: check filenames for basic platform validity (Bts:issue2755)
  * rebase: don't mark file as removed if missing in parent's manifest (Bts:issue2725)
  * rebase: preserve mq series order after rebasing (Bts:issue2849)
  * rebase: restore mq guards after rebasing (Bts:issue2107)
  * revset: report a parse error if a revset is not parsed completely (Bts:issue2654)
  * scmutil: improve path calculation for install-relative RC files (Bts:issue2841)
  * set NOT_CONTENT_INDEXED on .hg dir (Bts:issue2694)
  * sslutil: fall back to commonName when no dNSName in subjectAltName (Bts:issue2798)
  * subrepo: be more careful with deletions of .hgsub and .hgsubstate (Bts:issue2844)
  * subrepo: make stdin for svn a pipe for non-interactive use (Bts:issue2759)
  * subrepo: svn abort now depends on exit code (Bts:issue2833)
  * subrepo: be smarter about what's an absolute path (Bts:issue2808)
  * svn subrepo: attempt work around obstructed checkouts (Bts:issue2752)
  * svn subrepos: work around checkout obstructions (Bts:issue2752)
  * tags: catch more corruption during cache parsing (Bts:issue2779)
  * util: add Mac-specific check whether we're in a GUI session (Bts:issue2553)
  - changes in version 1.8.4
  * bookmarks: do not forward merged bookmark (Bts:issue1877)
  * changelog: convert user and desc from local encoding early
  * fix bookmarks rollback behavior
  * hgrc.5: document shell aliases
  * httprepo: proper handling of invalid responses without content-type (Bts:issue2019)
  * httprepo: send URL redirection notices to stderr (Bts:issue2828)
  * localrepo: don't add deleted files to list of modified/added files (Bts:issue2761)
  * localrepo: ignore tags to unknown nodes (Bts:issue2750)
  * mq: strip extra whitespace from node ids in header (Bts:issue2790)
  * rebase: restore mq guards after rebasing (Bts:issue2107)
  * revset: expand help for contains predicate
  * revset: note case-insensitive matches in keyword and user
  * revset: note case-sensitive match in grep
  * revset: report a parse error if a revset is not parsed completely (Bts:issue2654)
  * revset: the name is optional for the tag predicate
  * simplemerge: do not allow binary files to abort an entire merge
  * strip: make it clear that --force discards changes (Bts:issue310)
  * subrepo: don't crash when git .hgsubstate is empty (Bts:issue2716)
  * subrepo: make stdin for svn a pipe for non-interactive use (Bts:issue2759)
  * subrepo: respect non-default path for incoming/outgoing
  * subrepo: svn abort now depends on exit code (Bts:issue2833)
  * subrepo: use code from 71ea5b only if Python needs it (Bts:issue2795)
  * tags: catch more corruption during cache parsing (Bts:issue2779)
* Thu May 26 2011 wr@rosenauer.org
- update to version 1.8.3
  * convert: make filemap prune useless branch closing revs (issue2774)
  * encoding: avoid localstr when a string can be encoded losslessly (issue2763)
  * extdiff: fix broken symlinks handling (issue1909)
  * help config: explain that config files do not exist by default
  * hgweb: add bookmark labels to gitweb theme
  * hgweb: add missing bookmarks definition to coal/map
  * hgweb: add missing bookmarks templates to atom/rss styles
  * hgweb: add separate bookmarks listing to gitweb theme
  * hgweb: add separate bookmarks listing to monoblue theme
  * hgweb: detect change based on changelog size too
  * hgweb: fix inconsistant display of graphlog (issue1706)
  * hgweb: fix typo and inactive link in page_nav and page_header of gitweb's help
  * hgweb: fix typo in page-header of monoblue's help template
  * hgweb: format page_nav of gitweb/error.tmpl and add missing links
  * rebase: don't mark file as removed if missing in parent's manifest (issue2725)
  * subrepo: handle svn tracked/unknown directory collisions
  * subrepo: prevent url normalization from removing // in ssh paths (issue2556)
  * subrepo: tell Subversion when we are non-interactive (issue2759)
  * url: use a regex to hide unsupported ssh passwords (issue2754)
  * zeroconf: notify the Zeroconf threads when hg exits
* Sat Apr 16 2011 ammler@openttdcoop.org
- update to version 1.8.2
  * bookmarks: discard current bookmark if absent from the bookmarks (issue2692)
  * bookmarks: fix update of the current bookmark during rename
  * color: port to using ctypes (issue2687)
  * convert/svn: fix _iterfiles() output in root dir case (issue2647)
  * eol: do not abort when win32text is found, only warn
  * eol: use dirstate methods to clear dirstate
  * fix compiling of extensions for OS X and XCode 4.0
  * hgweb: add display of bookmarks for changelog and changeset
  * hgweb: add separate page with bookmarks listing
  * merge: avoid unlinking destination of merge when case changes (issue2715)
  * mq: do not let qrefresh write bad patch
  * pager: don't page stderr if it's being redirected (issue2541)
  * push/outgoing: print remote target path even if there's an error (issue2561)
  * subrepo: recognize scp-style paths as git URLs
  * templates: widen the graph canvas (issue2683)
- mercurial provides hg
* Fri Mar 25 2011 chris@computersalat.de
- update to version 1.8.1
  * annotate: rewrite to deal with crossed linkrevs (issue2682)
  * bookmark: fix invalidation of localrepo._bookmarkcurrent
  * cacert: improve error report when web.cacert file does not exist
  * contrib: update tcsh_completion for Mercurial 1.8
  * hgcia: accept "queued." xmlrpc return as success
  * hgweb: fix filelog rss links generation
  * hgweb: use tip in gitweb/monoblue filelog rss links (issue2677)
  * merge: back out single-parent fast-forward merge
  * merge: drop resolve state for mergers with identical contents (issue2680)
  * merge: improve unresolved conflicts warning (issue2681)
  * mergetools: add alternate registry keys for 32bit apps on 64bit O/S
  * mq: forbid commit of merge involving mq patches
  * subrepo: backout 67fbe566eff1, --force requires svn >= 1.5
  * subrepo: don't crash when git repo is missing
  * subrepo: handle svn tracked/unknown directory collisions
  * wix: drop bin/ folder from MSI installers (issue2673)
* Wed Mar  9 2011 wr@rosenauer.org
- Update to version 1.8
  Core
  * Bookmarks are now a core feature (see UpgradeNotes)
  * New listfile: pattern-matching (patterns)
  * Revset syntax supported by most commands
  * Performance improvements for reading large repository indexes
  * Certificate validation for HTTPS proxies
  Subrepos
  * New support for git subrepos
  * Various improvements to merge, update, and commit logic
  Extensions
  * eol: filter aliases for compatibility with win32text
  * mq: --exact option for qpush
  * mq: various robustness improvements
  * progress: remaining time estimates
* Tue Mar  1 2011 wr@rosenauer.org
- removed xz archive/handling again
* Thu Feb  3 2011 ammler@openttdcoop.org
- Update to version 1.7.5
  This is a quick bugfix release to include some fixes accidentally
  dropped from 1.7.4.
  * subrepo: fix update -C with svn subrepos when cwd != repo.root
  * subrepo: make update -C clean the working directory for svn subrepos
  * url: add --insecure option to bypass verification of ssl certificates
- Update to version 1.7.4
  This is a scheduled bugfix release that smooths out some of the
  rough edged introduced with 1.7.3's HTTPS certificate verification.
  * bookmarks: always write undo file
  * bookmarks: respect rollbacks dryrun parameter
  * hgrc.5: mention that web.cacerts are run through util.expandpath
  * opener: force copy on 'a'ppend if nlinks() returns 0 (issue1922)
  * subrepo: compare svn subrepo state to last committed revision
  * subrepo: do not report known files inside repositories as unknown
  * url: 'ssh known host'-like checking of fingerprints of HTTPS
    certificates (see CACertificates)
  * url: check subjectAltName when verifying ssl certificate
  * url: expand path for web.cacerts
  * url: fix UnicodeDecodeError on certificate verification error
* Sat Jan 15 2011 ammler@openttdcoop.org
- Add ca-bundle.pem to the global config
* Sun Jan  9 2011 wr@rosenauer.org
- Update to version 1.7.3 (regular bugfix release)
  * archive: don't set gzip filename header when there's no filename
  * checknlink: use two testfiles (issue2543)
  * churn: ignore trailing and leading spaces (issue2546)
  * date: fix matching of underspecified date ranges
  * eol: improve help on whether EOLs are changed in working copy or
    repository
  * fncachestore: copy dh directory before the manifest
  * hgweb: abort if config file isn't found
  * hook: assume relative path to hook is given from repo root
  * hook: fix import path handling for repo=None
  * https: use web.cacerts configuration from local repo to validate
    remote repo
  * https: warn when server certificate isn't verified (see
    CACertificates)
  * keyword: copy: when copied source is a symlink, follow it
  * patch: write .rej files without rewriting EOLs
  * strip: typo bugfix related to '--nobackup -> --no-backup' rename
    (issue2377)
  * tag: abort if not at a branch head (issue2552)
  * tag: don't check .hgtags status if --local passed
  * tag: fix uncommitted merge check and error message (issue2542)
  * util: fix ellipsis() not to break multi-byte sequence (issue2564)
  * util: work around behavior change in Python 2.7.1
  * windows.rename: eliminate temp name race (issue2571)
  * wix: add an ssl certificate file to the WiX installers (see
    CACertificates)
* Fri Dec  3 2010 wr@rosenauer.org
- Update to version 1.7.2
  * checknlink: return False if .hgtmp file preexists (issue2517)
  * commit: search both parents for missing copy revision (issue2484)
  * context: walk both parents for workingctx.ancestors()
  * convert/svn: fix changed files list upon directory replacements
  * hgwebdir: fix incorrect index generation for invalid paths (issue2023)
  * keyword: copy: when copied source is a symlink, follow it
  * mq: ignore subrepos (issue2499)
  * rebase: support --detach when null is common ancestor
  * subrepo: fix removing read-only svn files on Windows
  * subrepo: handle missing subrepo spec file as removed
  * subrepo: prune empty directories when removing svn subrepo
  * subrepo: use subprocess directly to avoid python 2.6 bug
  * util: do not crash on revisions with negative timestamp (issue2513)
  * util: do not recurse in makedirs if name is '' (issue2528)
* Mon Nov 22 2010 wr@rosenauer.org
- fix build for 11.1 and before by removing new docutils option
* Fri Nov 19 2010 wr@rosenauer.org
- Update to version 1.7.1
  * 1.7 clients broke support for pushing bookmarks with HTTP
  * alias: fall back to normal error handling for ambigious
    commands (issue2475)
  * bundlerepository: get rid of temporary bundle files (issue2478)
  * bundlerepository: test self.tempfile field, not tempfile module
  * eol: exclude .hgtags file from eol translation (issue2493)
  * log: fix log -rREV FILE when REV isnt the last filerev (issue2492)
  * opener: check hardlink count reporting (issue1866)
  * pushkey: force HTTP POST on push and add tests (issue2489)
  * revlog: fix descendants() if nullrev is in revs
  * subrepo: test & fix svn subrepo removal
* Wed Nov 10 2010 wr@rosenauer.org
- Update to version 1.7
  * new build and runtime requirement python-xml (hgcia extension)
  * added docutils to BuildRequires
  Core
    filelog: improve cmp performances (issue2273)
    patch: don't strip '#' lines from patch descriptions (issue2417)
    patch: when native patching fails (ui.patch is not set), don't
    retry with an external tool
    setup/hg: always load Mercurial from where it was installed.
    setup: user-friendly error message if Python headers are missing
    store: new unsupported and experimental parentdelta format
    (see UpgradeNotes)
    store: encode first period or space in filenames (issue1713)
    url: expand environment variables in [auth] settings (issue2328)
    url: check validity (notBefore/notAfter) using OpenSSL (issue2407)
  Commands
    addremove: use similarity 100 by default
    alias: add support for shell command aliases starting with
    '!' (see [alias] in hgrc(5))
    backout: add --tool argument for specifying merge tool
    backout: backout linearly by default instead of branching and
    merging (use --merge to get the former behaviour)
    dispatch: properly handle relative path aliases used with -R
    (issue2376)
    init: expand destination url as a configured paths
    log: do not --follow file that is deleted and recreated
    later (issue732)
    merge: don't detect copies as "divergent renames", make
    diagnostic message more helpful
    merge: add --tool argument to merge and resolve
    merge: handle no file parent in backwards merge (issue2364)
    tags: do not fail if tags.cache is corrupted (issue2444)
    templater: add "hex" filter and "children" keywords
    (see hg help templating)
  Subrepos
    support remapping of subrepository source paths
    (see [subpaths] in hgrc(5))
    make add, diff, incoming, outgoing and status commands
    recurse into subrepos with --subrepos/-S
    subrepo: add support for 'hg archive'
    subrepo: fix status check on SVN subrepos (issue2445)
  Revsets
    add id() and rev() to allow explicit references to changes
    by hash or rev (see hg help revsets)
    add min() function to complement max()
    add present() function to avoid lookup errors on possibly
    missing changesets
    rename tagged() to tag() and allow it to take an optional tag name
    strip: add revsets support
    add revsets support to bisect and update (issue1993)
    bookmarks: add a bookmark([name]) revset for referencing
    bookmarks
    transplant: add a transplanted(set) revset to get transplanted
    revisions
  hgweb
    add a help view for accessing the built-in documentation
    (see help link in hg serve)
    let HTTPS serve use more compatible but less secure encryption
    support very simple caching model (issue1845)
  Extensions
    color: better support for branches and mq guards
    convert: handle closed branch heads in hg-hg conversion
    (issue2185)
    convert: support darcs changelogs with bytes 0x7F-0xFF
    (issue2411)
    convert: deprecate --authors in preference for --authormap
    graphlog: support header and footer templates when using styles
    (issue2395)
    keyword: do not expand at all during diff
    keyword: support copy and rename
    mq: extend support for the --mq argument to extension commands
    mq: save qrefresh message for easy recovery in case it fails
    (issue2062)
    mq: support hg qimport --existing --name renametothis
    thatexistingpatch, fix --force case on Windows
    mq/qqueue: support renaming of active queue
    mq/qqueue: add --purge option to delete a queue and its patches
    pager: add global --pager=<auto/boolean> option
    patchbomb: add --confirm option to show series details and ask
    for confirmation
    patchbomb: let diffstat prompt only once with complete summary
    progress: support rebase and patchbomb
    rebase: re-add patches to mq repo after rebase
    strip: add --keep flag to avoid modifying working directory
    during strip
    strip: rename --nobackup option to --no-backup (issue2377)
    strip: support stripping multiple revisions
  contrib
    mergetools.hgrc: add vimdiff
    zsh completion: support bookmarks and patchbomb extensions
    zsh completion: add qpush --move option
* Mon Oct 11 2010 wr@rosenauer.org
- update to 1.6.4
  * archive: set date to 1980 for very old zip files
  * bookmarks: fix _bookmarks/lookup() reentrancy issue (issue2016)
  * context: fix filectx.undelete() (issue2388)
  * convert/darcs: handle non-ASCII metadata in darcs changelog (issue2354)
  * convert/svn: fix broken symlink renames in svn sink
  * core: use lexists() instead of exists() where appropriate
  * hgweb: Fix memory leak when using hg commands over http repositories
  * hgweb: correct Content-Type header values for archive downloads
  * log: include unmodified-in-merge files in log diff/stat (issue2383)
  * mq: always require --force when pushing patches (issue2363)
  * patch: do not overwrite broken untracked symlinks
  * patch: fix rename text to binary file (issue2400)
  * patch: fix target when patching broken symlinks (issue2368)
  * patch: upgrade to git patch when removing binary file
  * rename: do not overwrite existing broken symlinks
  * url: verify correctness of https server certificates (issue2407)
  * util: avoid using hashlib on Python < 2.5 (issue2278)
  * verify: fix "missing revlog!" errors for revlog format v0 and add test
* Mon Sep  6 2010 wr@rosenauer.org
- update to 1.6.3:
  * alias: make shadowing behavior more consistent (issue2054)
  * bisect: better message for unrelated starting revisions
  * bookmarks: Check if the bookmark to delete exists on the remote
  * bookmarks: guard against listing bookmarks on unsupported repos
  * chunkbuffer: use += rather than cStringIO to reduce memory footprint
  * convert: Using --dest-type svn crashed, if the source repo used tags
  * convert: properly set encoding for gnuarch converter
  * convert: use encoding.encoding instead of locale.getpreferredencoding()
  * graphlog: mark --branch as incompatible with --graph
  * http basic auth: reset redirect counter on new requests (issue2255)
  * httprepo: decompress stream incrementally to reduce memory usage
  * log: fix the bug 'hg log --stat -p == hg log --stat'
  * merge: drop reference to file contents after write
  * merge: move reverse-merge logic out of filemerge (issue2342)
  * merge: fix detection of conflict markers with checkconflicts enabled
  * mq: don't inherit default and default-push paths with --mq (issue2333)
  * resolve: updated help documentation for improved clarity
  * revlog: drop cache after use to save memory footprint
  * templatefilters: unnest uescape()
  * templates: add filenolink to raw style (issue2332)
  * url: expand vars in all [auth] settings (issue2328)
  * url: limit expansion to safe auth keys (Issue2328)
  * util: avoid using hashlib on Python < 2.5 (issue2278)
  * verify: initialize rp variable in case we hit out of memory
  * verify: reduce memory footprint when unpacking files
  * verify: report exceptions that don't have a str() method
- in case of !with_doc copy the man pages from the source tarball
* Wed Aug  4 2010 pascal.bleser@opensuse.org
- split out localization of messages into its own -lang subpackage, which reduces the size of the mercurial package by around 400kb
- the locale files are moved into the arch-independent %%{python_sitelib} instead of %%{python_sitearch} in order to have a noarch -lang subpackage
- use --record-rpm for the list of files
- update to 1.6.2:
  * fixes a regression in the color extension
- changes from 1.6.1:
  * alias: ensure checksignature() is applied directly to the command (issue2286)
  * bash/zsh completion: use HGPLAIN when invoking hg (issue2297)
  * bookmarks: don't allow name to contain whitespaces only
  * bookmarks: ensure current bookmark is updated when specified with -r .
  * bundle: lookup revisions after addbranchrevs
  * color/progress: subclass ui instead of using wrapfunction (issue2096)
  * commit: only warn when reopening the workdir's branch
  * dispatch: give better error message when cwd doesn't exist (issue2293)
  * doc: make sure we use our own code for generating man pages
  * filelog: cmp: don't read data if hashes are identical (issue2273)
  * filelog: test behaviour for data starting with "\1\n"
  * hg.clone: fix branch value when passing a repo object (issue2267)
  * hgweb.wsgi: add a URL to the corresponding wiki documentation
  * hgwebdir: allow pure relative globs in paths
  * hgwebdir: use template paths configured in the hgrc (issue2281)
  * init: create target directory recursively
  * inotify: check all components of filenames against hgignore (issue884)
  * keyword: move collecting of [keyword] patterns to reposetup (issue2303)
  * log: fix missing diff output for hg log -p in subdirectory
  * log: follow filenames through renames (issue647)
  * mail: ensure that Python2.4 to 2.7 use the same header format
  * mq: clarify the fact that qimport is trying to read a file
  * mq: cleanup status if applied mq is stripped (issue1881)
  * mq: fixed ENOENT when qrename to new/directory.patch
  * mq: reset self.added after the mq transaction instead of inside qimport
  * qpush --move: move the right patch even with comment lines
  * rebase: re-add patches to mq repo after rebase
  * revert: rename original to .orig instead of copying (issue2282)
  * revset: fix ancestor subset handling (issue2298)
  * runrst: try to be more helpful if docutils is not installed
  * tag: do not allow tag names to consist solely of whitespace (issue2307)
  * transplant: crash if repo.commit() finds nothing to commit
* Thu Jul 29 2010 wr@rosenauer.org
- install bash_completion file
* Mon Jul 19 2010 wr@rosenauer.org
- updated to version 1.6
  This release makes a couple small behavior changes:
  Upgrade Notes
  * hgweb.cgi and hgwebdir.cgi  combined (though old installs of
    either will continue to work)
  * hgweb and command line templates now require escaping of
    open braces ('\{') that aren't part of template expressions
  * hgweb now delivers output of external changeset hooks to
    clients
  * the churn extension lost the --progress flag (uses the
    ProgressExtension  instead)
  Core
  * addremove: optimize addremove -s100 by matching files by
    their SHA1 hashes
  * archive: auto-detect archive type by extension (issue2058)
  * commit: more friendly handling of new and closed named
    branches
  * hooks: provide pre- and post- hooks with parsed command line
    arguments
  * log: add --branch for filtering on named branch
  * log: add --stat for diffstat output
  * push: add --new-branch option to allow initial push of new
    branches
  * push: break infinite http recursion bug with Python 2.6.5
    (issue2179)
  * rollback: add -n/--dry-run flag, report what's being rolled
    back
  * subrepo: various fixes
  * summary: report copies and renames and add subrepo status
  * tag: add -e/--edit option for modifying the commit message
  * revsets: introduce a powerful query language for specifying
    revisions, see the manpage or hg help revsets
  Hgweb
  * unify and simplify hgweb.cgi and hgwebdir.cgi scripts
  * fix race in refreshing repo list (issue2188)
  * simplify hgweb.cgi, add help pointer
  * deliver shell hook output to client
  * allow --port=0 to specify "choose free port number
    automatically"
  * improved templater performance
  Help
  * add new hgweb, glossary, and revsets topics
  * numerous improvements to help text
  Extensions
  * acl: support for access control base on branches and
    user-defined or OS-level groups
  * acl: added support for pretxncommit, so that one can call
    the ACL hook at (?)
  * bookmarks: add support for pushing and pulling bookmarks
  * churn: add possibility to include/exclude paths
  * color: add support for Windows consoles
  * color: colorize based on output labels instead of parsing
    output
  * extdiff: add labels, read diff arguments from [merge-tools]
  * keyword: offer svn-like default keywordmaps
  * keyword: support (q)record
  * mq: add a line to hg summary
  * mq: qpush --move, reorder patch series and apply only the
    patch
  * progress: progress support for many more commands
  * rebase: add option to not commit after a collapsing
* Thu Jun  3 2010 wr@rosenauer.org
- updated to version 1.5.4
  * dispatch: include Python version in traceback
  * push: update help
  * status: avoid performance regression when no .hgsub is present
  * clone: fix performance issue with hardlinks and Windows shares
  * hgweb: fix race in refreshing repo list (issue2188)
  * hgrc: clarify that hgrc keys can be overridden and sections
    can be split
  * eol: new extension for managing file newlines based on a
    version controlled configuration file
  * pager: fork and exec pager as parent process with /bin/sh -c
  * rebase: stress that only local changesets should be rebased
  * convert/svn: close gettags() log stream (issue2196)
  * record: check that we are not committing a merge before patch
    selection
* Wed May 26 2010 wr@rosenauer.org
- updated to version 1.5.3
  * This is an unscheduled bugfix release to fix Issue2181
    (commit generates traceback on Nonetype).
  Also included:
  * various improvements to SVN conversion support
  * minor doc improvements
* Tue May 11 2010 wr@rosenauer.org
- updated to version 1.5.2
  * This is a monthly bugfix release with numerous minor fixes
* Sun Apr 11 2010 wr@rosenauer.org
- updated to version 1.5.1
  Core
  * improve warning on adding large files
  * expand ~ in auth filenames and aliases
  * several improvements to patch parsing
  * warn about attempts to use hg branch to switch branches
  * push: fix bug in prepush logic and its tests
  * hgweb: fix broken URLs of RSS/Atom feeds
  * subrepo: several bug fixes
  Extensions
  * acl: added support for '*' (everyone) in user list
  * progress: use stderr instead of stdout
  * schemes: add Kiln On Demand to default schemes
* Tue Mar  9 2010 wr@rosenauer.org
- updated to version 1.5:
  Behavior changes:
  * hg heads now shows all branch heads, use --topo for old
    behavior
  * hg annotate now follows copies and renames by default,
    use --no-follow for old behavior
  * the repo#name URL syntax now refers to all branch heads if
    name is a branch
  * servers now allow clone --uncompressed by default, set
    server.uncompressed=false for old behavior
  * the {file_copies} template now displays copies unconditionally,
    use {file_copies_switch} for old behavior
  * the templates/ directory has moved inside mercurial/
  * mq patches are automatically upgraded to git patches,
    use mq.git=keep for old behavior
  Core
  * improved behavior for named branches with heads command
  * new XML output template for logs
  * import extract multiple patches from emails, mboxes, files,
    and URLs
  * new patch.eol=auto option to ignore patch line-endings while
    preserving target file endings.
  * new -b/--branch option for clone, bundle, incoming, outgoing,
    pull, and push
  * new server.validate option to validate completeness of pushed
    changesets
  * subrepos now has basic Subversion support
  * support for SSL server certificates and improved IPv6 support
  * the HGPLAIN environment variable makes output more stable for
    scripts
  Extensions
  * new progress bar extension
  * mq: new --mq option to make regular commands operate on
    queue repository
  * mq: automatically upgrade conventional patches to git format
    where needed
  * color: add support for bookmarks, resolve -l, and churn
  - -diffstat
  * convert: two CVS history editing hooks
  * win32mbcs: add configuration to specify path encoding
  * zeroconf: many bug fixes
  * rebase: new --detach option for rebase
  Web Interface
  * improve navigation on log and graph pages
  * support for pluggable authorization
  * raw templates for tags/branches pages
  Help and Documentation
  * greatly improve error messages and command documentation
  * support extended documentation with --verbose
  * provide help for disabled extensions and commands
* Mon Feb  8 2010 wr@rosenauer.org
- updated to version 1.4.3:
  * Mercurial license has changed from GPLv2 to GPLv2+
  * speed up copy detection in merge, status, and diff
  * templates: fix relative path expansion on style setting
  * merge: fix merging of already-merged subrepos
  * summary: fix i18n issue reporting clean working directories
  * hgweb: improve IIS PATH_INFO handling
* Fri Jan  8 2010 wr@rosenauer.org
- updated to version 1.4.2:
  core:
  * config: raise ConfigError on non-existing include files
  * alias: do not crash when aliased command has no usage help text
  * auth: allow specifying auth sections in .hg/hgrc
  * patch: fix handling of chunk offsets
  * subrepo: add default path to new clones
  * docs: Fix rst2html detection
  extensions:
  * convert/svn: better handling of hg recursive call failure
  * convert/svn: make sink recover gracefully from empty changeset
  * keyword: fix interaction with transplant
  * mq: preserve --git flag when folding and merging patches
  * mq: qnew -f rejects merge working directories
  * mq: qpop: remove added files before re-adding removed files
  * patchbomb: handle repository#rev URLs correctly
  * share: use defaultdest to compute unspecified destination
  regression fixes:
  * fix to prepush logic when it creates new heads
  * fix qseries truncation
  other:
  * doc fixes: formatting, missing options
  * tests fixes (now less dependent on environment variables)
  * inotify fixes
  * keyword: allow RCSfile like CVS
  * share: fix a bad interaction with clone
  * show non-default branch names with summary -q
  * new schemes extension
  * i18n updates
* Wed Nov 25 2009 wr@rosenauer.org
- updated to version 1.4:
  core:
  * summary: new command summarizes current working state
  * tags: new tag cache greatly speeds up tag operations
  * diff: new --stat option to show diffstat
  * diff: add --reverse option to diff
  * subrepo: fix a bunch of issues with the experimental subrepo
    extension
  * status: fixes for behavior when working with clock skew
  * clone: new -u/--updaterev option
  * templater: new latesttag and latesttagdistance keywords
  * push/pull: handle some broken pipe errors during large
    transfers
  * config: environment variables and ~user constructs are
    expanded in pathnames
  hgweb:
  * fix for showing header lines in raw changeset diffs
  * try to send better error messages to the client
  * use config-supplied ordering by default in hgwebdir index
    pages
  * add web.descend option to disable showing all nested
    repositories in hgwebdir
  extensions:
  * mq: add -1 options to qapplied/qunapplied
  * patchbomb: add a --flag option to set a flag value in the
    Subject header
  * patchbomb: correctly handle Unicode domains (using the IDNA
    encoding scheme)
  * color: improve colorization of the qseries command
  * inotify: cleaner code, fixed pattern handling
  * zeroconf: show repository descriptions
  * rebase: some performance and correctness fixes
  * extdiff: add 3-way diff for merge changesets
  * convert: handle directory renaming in Darcs, fixed file
    renaming
  * relink: new extension which helps people re-hardlink their
    clones
  other:
  * contrib/shrink-revlog.py script that can significantly
    shrink some internal hg files
- add hgweb.cgi and hgwebdir.cgi to docdir
* Mon Jul 27 2009 tiwai@suse.de
- updated to version 1.3.1:
  * fixed excessive memory usage issues with diff and strip
  * fixed ssh performance issue on OS X
  * fixed slow calculation of branch heads
  * fixed handling of port numbers in URLs
  * fixed transaction handling exception
  * fixed incoming with graphlog extension
  * fixed slow commit in fetch extension
  * fixed loading of win32mbcs extension
  * fixed http username handling in acl extension
  * fixed subrepo path joining on Windows
  * allow update --check to cross branches
  * miscellaneous small doc and bug fixes
- fixed builds on SLE10
* Fri Jul  3 2009 tiwai@suse.de
- updated to version 1.3:
  * experimental support for sub-repositories
  * Python 2.3 is no longer supported
  * More read
  http://mercurial.selenic.com/wiki/WhatsNew
* Mon Apr 27 2009 tiwai@suse.de
- updated to version 1.2.1:
  * fixed version number build from tarball
  * fix allow_read logic for hgweb
  * improve handling of damaged revlogs in verify
  * keep .orig files when resolving
  * clear resolve state properly when rebasing
  * improve --command handling with bisect
  * fix diff against bundles
  * improve fetch logic for inactive branches
  * fix diffstat with notify
  * fix 'synthetic file adds' in CVS conversion
* Thu Mar  5 2009 tiwai@suse.de
- updated to version 1.2:
  * explicit closing of named branches via hg commit --close-branch
  * hg now accepts options given after arguments on the commandline
  * added translation support with initial Danish, Chinese and
    Italian translations
  * added optional pure-Python versions of C modules
  * pending changesets can now be accessed safely from hooks
  * diff: added -c option to show single changeset
  * many improvements to the documentation and online help topics
  * convert:
    o new support for perforce sources
    o improvements to handling cvs sources
    o improvements to handling gnu arch source
    o improvements to handling darcs sources
  * bookmarks:
    o set current to new when current is renamed
    o bookmarks: Add track.current option
    o bookmarks: add bookmarks to tags
  * mq: allow qpop when it won't invalidate any dirstate parents
  * patchbomb: respect diff settings
  * rebase: pull --rebase updates if there is nothing to rebase
  * bugzilla: updated to work with Bugzilla 3.2
  * zeroconf: added more documentation
  * hgk: add several color settings
  * the imerge extension has been removed (obsoleted by the resolve
    command)
* Thu Mar  5 2009 ro@suse.de
- ignore return value from subshells to fix build
* Thu Jan 29 2009 tiwai@suse.de
- disable all extensions as default, as requested by mercurial
  developer (bnc#466300)
* Thu Jan  8 2009 tiwai@suse.de
- updated to version 1.1.1:
  This is a bugfix release
  * make hgweb recursion optional (use '**' rather than '*')
  * fix fncache bug for directories ending in ' ' or '.'
  * require -a switch to resolve all files
  * improve help for resolve command
  * fix inotify interaction with bundle diffs
  * fix strange readline import error on Windows
  * fix non-existing target directory with git diffs
  * fix removing symlinks with git diffs
  * fix directory creation bug in patch
  * rebase: allow keeping branch names
  * fix a copy bug in the SVN converter
- updated to version 1.1.2:
  This is a minor release including one security fix and two
  minor bug fixes
  * improve path auditing (issue 1450)
  * fix date-related test failures in test suite
  * add graph controls to monoblue theme
* Thu Dec  4 2008 tiwai@suse.de
- updated to version 1.1:
  Major release, fix many bugs and improvements
  See http://www.selenic.com/mercurial/wiki/index.cgi/WhatsNew
* Tue Sep 30 2008 tiwai@suse.de
- Fix python-2.6 warnings in many commands;
  Backported python-2.6 wrapper patch from the upstream
* Fri Aug 15 2008 bwalle@suse.de
- updated to version 1.0.2:
  Security:
  * ensure that git patches only touch files within the
    repository (CVE-2008-2942)
  * hgweb: fix "allowpull" permission being ignored when pulling
    from hgweb
  General:
  * commit: handle copies of previously deleted files
  * bisect: allow for having multiple resulting changesets
  * fix Python 2.3 compatibility
  * make mq patches and .hgtags hardlink-safe again
  * various documentation improvements and fixes
  * fix a crash when addremove was called to replace a deleted
    directory with a symlink
  * make branches output easier to parse
  * fix inactive branches detection
  * hgweb: fix a crash in archive when the URL did not end in an
    expected archive type
  * sshserver: fix a crash in error handling code
  * fix the patchbomb extension on Windows by including email
    package in binary installations
  * handle symlinks when OS supports them but FS doesn't
  Extensions:
  * mq:
    o fix qrefresh losing metadata on the last refreshed file
    o fix a crash when renaming a patch just after a versioned
    queue initialization
    o fix the path of an explicitly specified queue when merging
    patches
    o strip now updates the working directory only if a parent
    was stripped
  * convert:
    o CVS: fix a crash when converting an existing working copy
    o monotone: fix quotes and backslashes parsing when reading
    commit messages
    o Subversion: correctly normalize paths and slashes
    o Subversion: fix compatibility with Subversion 1.5
    o git: allow converter to work with recent git releases
  * color:
    o get coloring for qseries --verbose output
    o improve mq extension detection
    o reset coloring before and after outputting colorized lines
  * highlight: fix a performance issue when detecting file types
    from large files
  * notify: take the diff options into account
* Fri Aug  8 2008 tiwai@suse.de
- enable acl extension as default (as was in the earlier versions)
- remove unneeded hgrc file
* Thu Aug  7 2008 bphilips@suse.de
- enable all the plugins that ship by default: /etc/mercurial/hgrc.d
* Mon Jun 30 2008 tiwai@suse.de
- VUL-0: mercurial: Insufficient input validation (bnc#404959)
* Tue Jun 10 2008 tiwai@suse.de
- updated to version 1.0.1:
  General:
  * several improvements in file copying implementation
  * allow different default value for diff.unified option
  * allow explicit use of internal merge tools
  Commands:
  * rename: doesn't unlink source file with --after
  * backout: reverse changeset belongs on current branch
  Extensions:
  * convert:
    o svn: improved detection of tags (has also become optional)
    o svn: improved branch handling
    o svn: better detection of file copies
  * mq:
    o expand terse command help texts
    o fix unimplemented qdiff -U option
  * highlight: fix compatibility with older Pygments (0.5.1)
  * churn: allow whitespaces as delimiter in aliases
  * pager: disable when used with --debugger
* Wed Apr 16 2008 tiwai@suse.de
- removed obsolete hbisect in the default hgrc
* Wed Mar 26 2008 crrodriguez@suse.de
- update to version 1.0
  * thousand of bugfixes, improvements and new features
    see http://www.selenic.com/pipermail/mercurial/2008-March/018014.html
* Mon Oct 22 2007 tiwai@suse.de
- updated to version 0.9.5:
  * lots of new feature and fixes,
    see http://www.selenic.com/pipermail/mercurial/2007-October/015150.html
* Wed Sep  5 2007 tiwai@suse.de
- fix error at invoking hgk (#307190)
* Wed Jun 27 2007 tiwai@suse.de
- updated to version 0.9.4:
  * support for symlinks
  * improved tag handling
  * improved merge handling of file and directory renames
  * improved named branch usability
  * numerous improvements to commands
  * generic pre- and post-command hooks
  * improved Windows support
  * basic BeOS and OpenVMS support
  * numerous bug fixes
  * extensions can now be specified in .hg/hgrc
  * new convert extension with CVS support
  * new graphlog extension
  * improved patchbomb extension
  * example FastCGI script
* Tue Dec 19 2006 tiwai@suse.de
- updated to version 0.9.3:
  * improved mq and hgk
  * branch support
  * proper changelog support in UTF-8
  * support for git-style patches
* Mon Jul 31 2006 tiwai@suse.de
- updated to version 0.9.1.
  * New extensions: acl, extdiff, purge
  * New hooks: preupdate
  * Improved performance: remove, clone
* Fri May 12 2006 tiwai@suse.de
- updated to version 0.9.
  * revlogNG support
  * mq extension as default
  * merge command
  * bisect command
  * diff and status are repo-wide
- require rcs for 3-way merge
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Mon Feb  6 2006 tiwai@suse.de
- fixed the extension of mq (for x86-64 problem)
- fixed requires and use standard suse rpm macros for python
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Sep 30 2005 tiwai@suse.de
- updated to version 0.7 + mq extension
- removed buggy bash completion.
* Wed Aug 31 2005 tiwai@suse.de
- updated to version 0.6c release.
* Tue Jul 26 2005 tiwai@suse.de
- use version 0.6b release.
- format man page via asciidoc and xmlto.
* Fri Jul  8 2005 tiwai@suse.de
- updated to snapshot 20050708.
* Mon Jul  4 2005 tiwai@suse.de
- fix the version number of snapshot release.
* Fri Jul  1 2005 tiwai@suse.de
- initial version: snapshot 20050701.
